"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AddButtonBgStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AddButtonBgStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AddButtonBgStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    fill: _AddButtonBgStyle.ValueType  # 0
    """默认填充"""
    stroke: _AddButtonBgStyle.ValueType  # 1
    """描边"""
    gray: _AddButtonBgStyle.ValueType  # 2
    """置灰"""

class AddButtonBgStyle(_AddButtonBgStyle, metaclass=_AddButtonBgStyleEnumTypeWrapper):
    """"""

fill: AddButtonBgStyle.ValueType  # 0
"""默认填充"""
stroke: AddButtonBgStyle.ValueType  # 1
"""描边"""
gray: AddButtonBgStyle.ValueType  # 2
"""置灰"""
global___AddButtonBgStyle = AddButtonBgStyle

class _AddButtonType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AddButtonTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AddButtonType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    bt_none: _AddButtonType.ValueType  # 0
    """占位"""
    bt_jump: _AddButtonType.ValueType  # 1
    """跳转"""
    bt_button: _AddButtonType.ValueType  # 2
    """按钮"""

class AddButtonType(_AddButtonType, metaclass=_AddButtonTypeEnumTypeWrapper):
    """按钮类型"""

bt_none: AddButtonType.ValueType  # 0
"""占位"""
bt_jump: AddButtonType.ValueType  # 1
"""跳转"""
bt_button: AddButtonType.ValueType  # 2
"""按钮"""
global___AddButtonType = AddButtonType

class _AdditionVoteState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionVoteStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionVoteState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    addition_vote_state_none: _AdditionVoteState.ValueType  # 0
    """"""
    addition_vote_state_open: _AdditionVoteState.ValueType  # 1
    """"""
    addition_vote_state_close: _AdditionVoteState.ValueType  # 2
    """"""

class AdditionVoteState(_AdditionVoteState, metaclass=_AdditionVoteStateEnumTypeWrapper):
    """投票状态"""

addition_vote_state_none: AdditionVoteState.ValueType  # 0
""""""
addition_vote_state_open: AdditionVoteState.ValueType  # 1
""""""
addition_vote_state_close: AdditionVoteState.ValueType  # 2
""""""
global___AdditionVoteState = AdditionVoteState

class _AdditionVoteType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionVoteTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionVoteType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    addition_vote_type_none: _AdditionVoteType.ValueType  # 0
    """"""
    addition_vote_type_word: _AdditionVoteType.ValueType  # 1
    """"""
    addition_vote_type_pic: _AdditionVoteType.ValueType  # 2
    """"""
    addition_vote_type_default: _AdditionVoteType.ValueType  # 3
    """"""

class AdditionVoteType(_AdditionVoteType, metaclass=_AdditionVoteTypeEnumTypeWrapper):
    """投票类型"""

addition_vote_type_none: AdditionVoteType.ValueType  # 0
""""""
addition_vote_type_word: AdditionVoteType.ValueType  # 1
""""""
addition_vote_type_pic: AdditionVoteType.ValueType  # 2
""""""
addition_vote_type_default: AdditionVoteType.ValueType  # 3
""""""
global___AdditionVoteType = AdditionVoteType

class _AdditionalButtonClickType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionalButtonClickTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionalButtonClickType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    click_none: _AdditionalButtonClickType.ValueType  # 0
    """通用按钮"""
    click_up: _AdditionalButtonClickType.ValueType  # 1
    """预约卡按钮"""

class AdditionalButtonClickType(_AdditionalButtonClickType, metaclass=_AdditionalButtonClickTypeEnumTypeWrapper):
    """附加卡按钮点击类型"""

click_none: AdditionalButtonClickType.ValueType  # 0
"""通用按钮"""
click_up: AdditionalButtonClickType.ValueType  # 1
"""预约卡按钮"""
global___AdditionalButtonClickType = AdditionalButtonClickType

class _AdditionalButtonStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionalButtonStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionalButtonStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    none: _AdditionalButtonStatus.ValueType  # 0
    """"""
    uncheck: _AdditionalButtonStatus.ValueType  # 1
    """"""
    check: _AdditionalButtonStatus.ValueType  # 2
    """"""

class AdditionalButtonStatus(_AdditionalButtonStatus, metaclass=_AdditionalButtonStatusEnumTypeWrapper):
    """"""

none: AdditionalButtonStatus.ValueType  # 0
""""""
uncheck: AdditionalButtonStatus.ValueType  # 1
""""""
check: AdditionalButtonStatus.ValueType  # 2
""""""
global___AdditionalButtonStatus = AdditionalButtonStatus

class _AdditionalType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionalTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionalType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    additional_none: _AdditionalType.ValueType  # 0
    """占位"""
    additional_type_pgc: _AdditionalType.ValueType  # 1
    """附加卡-追番"""
    additional_type_goods: _AdditionalType.ValueType  # 2
    """附加卡-商品"""
    additional_type_vote: _AdditionalType.ValueType  # 3
    """附加卡投票"""
    additional_type_common: _AdditionalType.ValueType  # 4
    """附加通用卡"""
    additional_type_esport: _AdditionalType.ValueType  # 5
    """附加电竞卡"""
    additional_type_up_rcmd: _AdditionalType.ValueType  # 6
    """附加UP主推荐卡"""
    additional_type_ugc: _AdditionalType.ValueType  # 7
    """附加卡-ugc"""
    additional_type_up_reservation: _AdditionalType.ValueType  # 8
    """UP主预约卡"""

class AdditionalType(_AdditionalType, metaclass=_AdditionalTypeEnumTypeWrapper):
    """枚举-动态附加卡"""

additional_none: AdditionalType.ValueType  # 0
"""占位"""
additional_type_pgc: AdditionalType.ValueType  # 1
"""附加卡-追番"""
additional_type_goods: AdditionalType.ValueType  # 2
"""附加卡-商品"""
additional_type_vote: AdditionalType.ValueType  # 3
"""附加卡投票"""
additional_type_common: AdditionalType.ValueType  # 4
"""附加通用卡"""
additional_type_esport: AdditionalType.ValueType  # 5
"""附加电竞卡"""
additional_type_up_rcmd: AdditionalType.ValueType  # 6
"""附加UP主推荐卡"""
additional_type_ugc: AdditionalType.ValueType  # 7
"""附加卡-ugc"""
additional_type_up_reservation: AdditionalType.ValueType  # 8
"""UP主预约卡"""
global___AdditionalType = AdditionalType

class _DescType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DescTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DescType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    desc_type_none: _DescType.ValueType  # 0
    """占位"""
    desc_type_text: _DescType.ValueType  # 1
    """文本"""
    desc_type_aite: _DescType.ValueType  # 2
    """@"""
    desc_type_lottery: _DescType.ValueType  # 3
    """抽奖"""
    desc_type_vote: _DescType.ValueType  # 4
    """投票"""
    desc_type_topic: _DescType.ValueType  # 5
    """话题"""
    desc_type_goods: _DescType.ValueType  # 6
    """商品"""
    desc_type_bv: _DescType.ValueType  # 7
    """bv"""
    desc_type_av: _DescType.ValueType  # 8
    """av"""
    desc_type_emoji: _DescType.ValueType  # 9
    """表情"""
    desc_type_user: _DescType.ValueType  # 10
    """外露用户"""
    desc_type_cv: _DescType.ValueType  # 11
    """专栏"""
    desc_type_vc: _DescType.ValueType  # 12
    """小视频"""
    desc_type_web: _DescType.ValueType  # 13
    """网址"""
    desc_type_taobao: _DescType.ValueType  # 14
    """淘宝"""
    desc_type_mail: _DescType.ValueType  # 15
    """邮箱"""
    desc_type_ogv_season: _DescType.ValueType  # 16
    """番剧season"""
    desc_type_ogv_ep: _DescType.ValueType  # 17
    """番剧ep"""

class DescType(_DescType, metaclass=_DescTypeEnumTypeWrapper):
    """文本类型"""

desc_type_none: DescType.ValueType  # 0
"""占位"""
desc_type_text: DescType.ValueType  # 1
"""文本"""
desc_type_aite: DescType.ValueType  # 2
"""@"""
desc_type_lottery: DescType.ValueType  # 3
"""抽奖"""
desc_type_vote: DescType.ValueType  # 4
"""投票"""
desc_type_topic: DescType.ValueType  # 5
"""话题"""
desc_type_goods: DescType.ValueType  # 6
"""商品"""
desc_type_bv: DescType.ValueType  # 7
"""bv"""
desc_type_av: DescType.ValueType  # 8
"""av"""
desc_type_emoji: DescType.ValueType  # 9
"""表情"""
desc_type_user: DescType.ValueType  # 10
"""外露用户"""
desc_type_cv: DescType.ValueType  # 11
"""专栏"""
desc_type_vc: DescType.ValueType  # 12
"""小视频"""
desc_type_web: DescType.ValueType  # 13
"""网址"""
desc_type_taobao: DescType.ValueType  # 14
"""淘宝"""
desc_type_mail: DescType.ValueType  # 15
"""邮箱"""
desc_type_ogv_season: DescType.ValueType  # 16
"""番剧season"""
desc_type_ogv_ep: DescType.ValueType  # 17
"""番剧ep"""
global___DescType = DescType

class _DisableState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DisableStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DisableState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    highlight: _DisableState.ValueType  # 0
    """高亮"""
    gary: _DisableState.ValueType  # 1
    """置灰(按钮不可点击)"""

class DisableState(_DisableState, metaclass=_DisableStateEnumTypeWrapper):
    """"""

highlight: DisableState.ValueType  # 0
"""高亮"""
gary: DisableState.ValueType  # 1
"""置灰(按钮不可点击)"""
global___DisableState = DisableState

class _DynExtendType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynExtendTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynExtendType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    dyn_ext_type_none: _DynExtendType.ValueType  # 0
    """占位"""
    dyn_ext_type_topic: _DynExtendType.ValueType  # 1
    """话题小卡"""
    dyn_ext_type_lbs: _DynExtendType.ValueType  # 2
    """lbs小卡"""
    dyn_ext_type_hot: _DynExtendType.ValueType  # 3
    """热门小卡"""
    dyn_ext_type_game: _DynExtendType.ValueType  # 4
    """游戏小卡"""
    dyn_ext_type_common: _DynExtendType.ValueType  # 5
    """通用小卡"""
    dyn_ext_type_biliCut: _DynExtendType.ValueType  # 6
    """必剪小卡"""
    dyn_ext_type_ogv: _DynExtendType.ValueType  # 7
    """ogv小卡"""
    dyn_ext_type_auto_ogv: _DynExtendType.ValueType  # 8
    """自动附加ogv小卡"""

class DynExtendType(_DynExtendType, metaclass=_DynExtendTypeEnumTypeWrapper):
    """动态小卡类型"""

dyn_ext_type_none: DynExtendType.ValueType  # 0
"""占位"""
dyn_ext_type_topic: DynExtendType.ValueType  # 1
"""话题小卡"""
dyn_ext_type_lbs: DynExtendType.ValueType  # 2
"""lbs小卡"""
dyn_ext_type_hot: DynExtendType.ValueType  # 3
"""热门小卡"""
dyn_ext_type_game: DynExtendType.ValueType  # 4
"""游戏小卡"""
dyn_ext_type_common: DynExtendType.ValueType  # 5
"""通用小卡"""
dyn_ext_type_biliCut: DynExtendType.ValueType  # 6
"""必剪小卡"""
dyn_ext_type_ogv: DynExtendType.ValueType  # 7
"""ogv小卡"""
dyn_ext_type_auto_ogv: DynExtendType.ValueType  # 8
"""自动附加ogv小卡"""
global___DynExtendType = DynExtendType

class _DynModuleType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynModuleTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynModuleType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    module_none: _DynModuleType.ValueType  # 0
    """占位"""
    module_author: _DynModuleType.ValueType  # 1
    """发布人模块"""
    module_dispute: _DynModuleType.ValueType  # 2
    """争议小黄条"""
    module_desc: _DynModuleType.ValueType  # 3
    """描述文案"""
    module_dynamic: _DynModuleType.ValueType  # 4
    """动态卡片"""
    module_forward: _DynModuleType.ValueType  # 5
    """转发模块"""
    module_likeUser: _DynModuleType.ValueType  # 6
    """点赞用户(废弃)"""
    module_extend: _DynModuleType.ValueType  # 7
    """小卡模块"""
    module_additional: _DynModuleType.ValueType  # 8
    """附加卡"""
    module_stat: _DynModuleType.ValueType  # 9
    """计数信息"""
    module_fold: _DynModuleType.ValueType  # 10
    """折叠"""
    module_comment: _DynModuleType.ValueType  # 11
    """评论外露(废弃)"""
    module_interaction: _DynModuleType.ValueType  # 12
    """外露交互模块(点赞、评论)"""
    module_author_forward: _DynModuleType.ValueType  # 13
    """转发卡的发布人模块"""
    module_ad: _DynModuleType.ValueType  # 14
    """广告卡模块"""
    module_banner: _DynModuleType.ValueType  # 15
    """通栏模块"""
    module_item_null: _DynModuleType.ValueType  # 16
    """获取物料失败模块"""
    module_share_info: _DynModuleType.ValueType  # 17
    """分享组件"""
    module_recommend: _DynModuleType.ValueType  # 18
    """相关推荐模块"""
    module_stat_forward: _DynModuleType.ValueType  # 19
    """转发卡计数信息"""
    module_top: _DynModuleType.ValueType  # 20
    """顶部模块"""
    module_bottom: _DynModuleType.ValueType  # 21
    """底部模块"""

class DynModuleType(_DynModuleType, metaclass=_DynModuleTypeEnumTypeWrapper):
    """动态模块类型"""

module_none: DynModuleType.ValueType  # 0
"""占位"""
module_author: DynModuleType.ValueType  # 1
"""发布人模块"""
module_dispute: DynModuleType.ValueType  # 2
"""争议小黄条"""
module_desc: DynModuleType.ValueType  # 3
"""描述文案"""
module_dynamic: DynModuleType.ValueType  # 4
"""动态卡片"""
module_forward: DynModuleType.ValueType  # 5
"""转发模块"""
module_likeUser: DynModuleType.ValueType  # 6
"""点赞用户(废弃)"""
module_extend: DynModuleType.ValueType  # 7
"""小卡模块"""
module_additional: DynModuleType.ValueType  # 8
"""附加卡"""
module_stat: DynModuleType.ValueType  # 9
"""计数信息"""
module_fold: DynModuleType.ValueType  # 10
"""折叠"""
module_comment: DynModuleType.ValueType  # 11
"""评论外露(废弃)"""
module_interaction: DynModuleType.ValueType  # 12
"""外露交互模块(点赞、评论)"""
module_author_forward: DynModuleType.ValueType  # 13
"""转发卡的发布人模块"""
module_ad: DynModuleType.ValueType  # 14
"""广告卡模块"""
module_banner: DynModuleType.ValueType  # 15
"""通栏模块"""
module_item_null: DynModuleType.ValueType  # 16
"""获取物料失败模块"""
module_share_info: DynModuleType.ValueType  # 17
"""分享组件"""
module_recommend: DynModuleType.ValueType  # 18
"""相关推荐模块"""
module_stat_forward: DynModuleType.ValueType  # 19
"""转发卡计数信息"""
module_top: DynModuleType.ValueType  # 20
"""顶部模块"""
module_bottom: DynModuleType.ValueType  # 21
"""底部模块"""
global___DynModuleType = DynModuleType

class _DynUriType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynUriTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynUriType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    dyn_uri_type_none: _DynUriType.ValueType  # 0
    """"""
    dyn_uri_type_direct: _DynUriType.ValueType  # 1
    """直接跳转对应uri"""
    dyn_uri_type_suffix: _DynUriType.ValueType  # 2
    """作为后缀拼接"""

class DynUriType(_DynUriType, metaclass=_DynUriTypeEnumTypeWrapper):
    """"""

dyn_uri_type_none: DynUriType.ValueType  # 0
""""""
dyn_uri_type_direct: DynUriType.ValueType  # 1
"""直接跳转对应uri"""
dyn_uri_type_suffix: DynUriType.ValueType  # 2
"""作为后缀拼接"""
global___DynUriType = DynUriType

class _DynamicType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynamicTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynamicType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    dyn_none: _DynamicType.ValueType  # 0
    """占位"""
    forward: _DynamicType.ValueType  # 1
    """转发"""
    av: _DynamicType.ValueType  # 2
    """稿件: ugc、小视频、短视频、UGC转PGC"""
    pgc: _DynamicType.ValueType  # 3
    """pgc：番剧、PGC番剧、PGC电影、PGC电视剧、PGC国创、PGC纪录片"""
    courses: _DynamicType.ValueType  # 4
    """付费更新批次"""
    fold: _DynamicType.ValueType  # 5
    """折叠"""
    word: _DynamicType.ValueType  # 6
    """纯文字"""
    draw: _DynamicType.ValueType  # 7
    """图文"""
    article: _DynamicType.ValueType  # 8
    """专栏 原仅phone端"""
    music: _DynamicType.ValueType  # 9
    """音频 原仅phone端"""
    common_square: _DynamicType.ValueType  # 10
    """通用卡 方形"""
    common_vertical: _DynamicType.ValueType  # 11
    """通用卡 竖形"""
    live: _DynamicType.ValueType  # 12
    """直播卡 只有转发态"""
    medialist: _DynamicType.ValueType  # 13
    """播单 原仅phone端 只有转发态"""
    courses_season: _DynamicType.ValueType  # 14
    """付费更新批次 只有转发态"""
    ad: _DynamicType.ValueType  # 15
    """广告卡"""
    applet: _DynamicType.ValueType  # 16
    """小程序卡"""
    subscription: _DynamicType.ValueType  # 17
    """订阅卡"""
    live_rcmd: _DynamicType.ValueType  # 18
    """直播推荐卡"""
    banner: _DynamicType.ValueType  # 19
    """通栏"""
    ugc_season: _DynamicType.ValueType  # 20
    """合集卡"""
    subscription_new: _DynamicType.ValueType  # 21
    """新订阅卡"""

class DynamicType(_DynamicType, metaclass=_DynamicTypeEnumTypeWrapper):
    """枚举-动态类型"""

dyn_none: DynamicType.ValueType  # 0
"""占位"""
forward: DynamicType.ValueType  # 1
"""转发"""
av: DynamicType.ValueType  # 2
"""稿件: ugc、小视频、短视频、UGC转PGC"""
pgc: DynamicType.ValueType  # 3
"""pgc：番剧、PGC番剧、PGC电影、PGC电视剧、PGC国创、PGC纪录片"""
courses: DynamicType.ValueType  # 4
"""付费更新批次"""
fold: DynamicType.ValueType  # 5
"""折叠"""
word: DynamicType.ValueType  # 6
"""纯文字"""
draw: DynamicType.ValueType  # 7
"""图文"""
article: DynamicType.ValueType  # 8
"""专栏 原仅phone端"""
music: DynamicType.ValueType  # 9
"""音频 原仅phone端"""
common_square: DynamicType.ValueType  # 10
"""通用卡 方形"""
common_vertical: DynamicType.ValueType  # 11
"""通用卡 竖形"""
live: DynamicType.ValueType  # 12
"""直播卡 只有转发态"""
medialist: DynamicType.ValueType  # 13
"""播单 原仅phone端 只有转发态"""
courses_season: DynamicType.ValueType  # 14
"""付费更新批次 只有转发态"""
ad: DynamicType.ValueType  # 15
"""广告卡"""
applet: DynamicType.ValueType  # 16
"""小程序卡"""
subscription: DynamicType.ValueType  # 17
"""订阅卡"""
live_rcmd: DynamicType.ValueType  # 18
"""直播推荐卡"""
banner: DynamicType.ValueType  # 19
"""通栏"""
ugc_season: DynamicType.ValueType  # 20
"""合集卡"""
subscription_new: DynamicType.ValueType  # 21
"""新订阅卡"""
global___DynamicType = DynamicType

class _EmojiType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EmojiTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EmojiType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    emoji_none: _EmojiType.ValueType  # 0
    """占位"""
    emoji_old: _EmojiType.ValueType  # 1
    """emoji旧类型"""
    emoji_new: _EmojiType.ValueType  # 2
    """emoji新类型"""
    vip: _EmojiType.ValueType  # 3
    """大会员表情"""

class EmojiType(_EmojiType, metaclass=_EmojiTypeEnumTypeWrapper):
    """表情包类型"""

emoji_none: EmojiType.ValueType  # 0
"""占位"""
emoji_old: EmojiType.ValueType  # 1
"""emoji旧类型"""
emoji_new: EmojiType.ValueType  # 2
"""emoji新类型"""
vip: EmojiType.ValueType  # 3
"""大会员表情"""
global___EmojiType = EmojiType

class _EspaceStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EspaceStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EspaceStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    moba: _EspaceStyle.ValueType  # 0
    """moba类"""

class EspaceStyle(_EspaceStyle, metaclass=_EspaceStyleEnumTypeWrapper):
    """附加大卡-电竞卡样式"""

moba: EspaceStyle.ValueType  # 0
"""moba类"""
global___EspaceStyle = EspaceStyle

class _FoldType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FoldTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FoldType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FoldTypeZore: _FoldType.ValueType  # 0
    """占位"""
    FoldTypePublish: _FoldType.ValueType  # 1
    """用户发布折叠"""
    FoldTypeFrequent: _FoldType.ValueType  # 2
    """转发超频折叠"""
    FoldTypeUnite: _FoldType.ValueType  # 3
    """联合投稿折叠"""
    FoldTypeLimit: _FoldType.ValueType  # 4
    """动态受限折叠"""

class FoldType(_FoldType, metaclass=_FoldTypeEnumTypeWrapper):
    """折叠类型"""

FoldTypeZore: FoldType.ValueType  # 0
"""占位"""
FoldTypePublish: FoldType.ValueType  # 1
"""用户发布折叠"""
FoldTypeFrequent: FoldType.ValueType  # 2
"""转发超频折叠"""
FoldTypeUnite: FoldType.ValueType  # 3
"""联合投稿折叠"""
FoldTypeLimit: FoldType.ValueType  # 4
"""动态受限折叠"""
global___FoldType = FoldType

class _FollowType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FollowTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FollowType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ft_not_follow: _FollowType.ValueType  # 0
    """"""
    ft_follow: _FollowType.ValueType  # 1
    """"""

class FollowType(_FollowType, metaclass=_FollowTypeEnumTypeWrapper):
    """"""

ft_not_follow: FollowType.ValueType  # 0
""""""
ft_follow: FollowType.ValueType  # 1
""""""
global___FollowType = FollowType

class _HighlightTextStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HighlightTextStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HighlightTextStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    style_none: _HighlightTextStyle.ValueType  # 0
    """默认"""
    style_highlight: _HighlightTextStyle.ValueType  # 1
    """高亮"""

class HighlightTextStyle(_HighlightTextStyle, metaclass=_HighlightTextStyleEnumTypeWrapper):
    """文本高亮枚举"""

style_none: HighlightTextStyle.ValueType  # 0
"""默认"""
style_highlight: HighlightTextStyle.ValueType  # 1
"""高亮"""
global___HighlightTextStyle = HighlightTextStyle

class _ImageStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ImageStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ImageStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    add_style_vertical: _ImageStyle.ValueType  # 0
    """"""
    add_style_square: _ImageStyle.ValueType  # 1
    """"""

class ImageStyle(_ImageStyle, metaclass=_ImageStyleEnumTypeWrapper):
    """枚举-附加卡样式"""

add_style_vertical: ImageStyle.ValueType  # 0
""""""
add_style_square: ImageStyle.ValueType  # 1
""""""
global___ImageStyle = ImageStyle

class _LiveState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LiveStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LiveState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    live_none: _LiveState.ValueType  # 0
    """未直播"""
    live_live: _LiveState.ValueType  # 1
    """直播中"""
    live_rotation: _LiveState.ValueType  # 2
    """轮播中"""

class LiveState(_LiveState, metaclass=_LiveStateEnumTypeWrapper):
    """直播状态"""

live_none: LiveState.ValueType  # 0
"""未直播"""
live_live: LiveState.ValueType  # 1
"""直播中"""
live_rotation: LiveState.ValueType  # 2
"""轮播中"""
global___LiveState = LiveState

class _LocalIconType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LocalIconTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LocalIconType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    local_icon_comment: _LocalIconType.ValueType  # 0
    """"""
    local_icon_like: _LocalIconType.ValueType  # 1
    """"""

class LocalIconType(_LocalIconType, metaclass=_LocalIconTypeEnumTypeWrapper):
    """外露模块类型"""

local_icon_comment: LocalIconType.ValueType  # 0
""""""
local_icon_like: LocalIconType.ValueType  # 1
""""""
global___LocalIconType = LocalIconType

class _MdlDynCommonType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MdlDynCommonTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MdlDynCommonType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    mdl_dyn_common_none: _MdlDynCommonType.ValueType  # 0
    """"""
    mdl_dyn_common_square: _MdlDynCommonType.ValueType  # 1
    """"""
    mdl_dyn_common_vertica: _MdlDynCommonType.ValueType  # 2
    """"""

class MdlDynCommonType(_MdlDynCommonType, metaclass=_MdlDynCommonTypeEnumTypeWrapper):
    """"""

mdl_dyn_common_none: MdlDynCommonType.ValueType  # 0
""""""
mdl_dyn_common_square: MdlDynCommonType.ValueType  # 1
""""""
mdl_dyn_common_vertica: MdlDynCommonType.ValueType  # 2
""""""
global___MdlDynCommonType = MdlDynCommonType

class _MdlDynDrawTagType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MdlDynDrawTagTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MdlDynDrawTagType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    mdl_draw_tag_none: _MdlDynDrawTagType.ValueType  # 0
    """占位"""
    mdl_draw_tag_common: _MdlDynDrawTagType.ValueType  # 1
    """普通标签"""
    mdl_draw_tag_goods: _MdlDynDrawTagType.ValueType  # 2
    """商品标签"""
    mdl_draw_tag_user: _MdlDynDrawTagType.ValueType  # 3
    """用户昵称"""
    mdl_draw_tag_topic: _MdlDynDrawTagType.ValueType  # 4
    """话题名称"""
    mdl_draw_tag_lbs: _MdlDynDrawTagType.ValueType  # 5
    """lbs标签"""

class MdlDynDrawTagType(_MdlDynDrawTagType, metaclass=_MdlDynDrawTagTypeEnumTypeWrapper):
    """图文标签类型"""

mdl_draw_tag_none: MdlDynDrawTagType.ValueType  # 0
"""占位"""
mdl_draw_tag_common: MdlDynDrawTagType.ValueType  # 1
"""普通标签"""
mdl_draw_tag_goods: MdlDynDrawTagType.ValueType  # 2
"""商品标签"""
mdl_draw_tag_user: MdlDynDrawTagType.ValueType  # 3
"""用户昵称"""
mdl_draw_tag_topic: MdlDynDrawTagType.ValueType  # 4
"""话题名称"""
mdl_draw_tag_lbs: MdlDynDrawTagType.ValueType  # 5
"""lbs标签"""
global___MdlDynDrawTagType = MdlDynDrawTagType

class _MdlDynSubscriptionNewStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MdlDynSubscriptionNewStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MdlDynSubscriptionNewStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    mdl_dyn_subscription_new_style_nont: _MdlDynSubscriptionNewStyle.ValueType  # 0
    """占位"""
    mdl_dyn_subscription_new_style_live: _MdlDynSubscriptionNewStyle.ValueType  # 1
    """直播"""
    mdl_dyn_subscription_new_style_draw: _MdlDynSubscriptionNewStyle.ValueType  # 2
    """图文"""

class MdlDynSubscriptionNewStyle(_MdlDynSubscriptionNewStyle, metaclass=_MdlDynSubscriptionNewStyleEnumTypeWrapper):
    """"""

mdl_dyn_subscription_new_style_nont: MdlDynSubscriptionNewStyle.ValueType  # 0
"""占位"""
mdl_dyn_subscription_new_style_live: MdlDynSubscriptionNewStyle.ValueType  # 1
"""直播"""
mdl_dyn_subscription_new_style_draw: MdlDynSubscriptionNewStyle.ValueType  # 2
"""图文"""
global___MdlDynSubscriptionNewStyle = MdlDynSubscriptionNewStyle

class _MediaType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MediaTypeNone: _MediaType.ValueType  # 0
    """本地"""
    MediaTypeUGC: _MediaType.ValueType  # 1
    """UGC"""
    MediaTypePGC: _MediaType.ValueType  # 2
    """PGC"""
    MediaTypeLive: _MediaType.ValueType  # 3
    """直播"""
    MediaTypeVCS: _MediaType.ValueType  # 4
    """小视频"""

class MediaType(_MediaType, metaclass=_MediaTypeEnumTypeWrapper):
    """播放器类型"""

MediaTypeNone: MediaType.ValueType  # 0
"""本地"""
MediaTypeUGC: MediaType.ValueType  # 1
"""UGC"""
MediaTypePGC: MediaType.ValueType  # 2
"""PGC"""
MediaTypeLive: MediaType.ValueType  # 3
"""直播"""
MediaTypeVCS: MediaType.ValueType  # 4
"""小视频"""
global___MediaType = MediaType

class _ModuleAuthorBadgeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModuleAuthorBadgeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModuleAuthorBadgeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    module_author_badge_type_none: _ModuleAuthorBadgeType.ValueType  # 0
    """占位"""
    module_author_badge_type_threePoint: _ModuleAuthorBadgeType.ValueType  # 1
    """三点"""
    module_author_badge_type_button: _ModuleAuthorBadgeType.ValueType  # 2
    """按钮类型"""
    module_author_badge_type_weight: _ModuleAuthorBadgeType.ValueType  # 3
    """提权"""

class ModuleAuthorBadgeType(_ModuleAuthorBadgeType, metaclass=_ModuleAuthorBadgeTypeEnumTypeWrapper):
    """右侧操作区域样式枚举"""

module_author_badge_type_none: ModuleAuthorBadgeType.ValueType  # 0
"""占位"""
module_author_badge_type_threePoint: ModuleAuthorBadgeType.ValueType  # 1
"""三点"""
module_author_badge_type_button: ModuleAuthorBadgeType.ValueType  # 2
"""按钮类型"""
module_author_badge_type_weight: ModuleAuthorBadgeType.ValueType  # 3
"""提权"""
global___ModuleAuthorBadgeType = ModuleAuthorBadgeType

class _ModuleBannerType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModuleBannerTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModuleBannerType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    module_banner_type_none: _ModuleBannerType.ValueType  # 0
    """"""
    module_banner_type_user: _ModuleBannerType.ValueType  # 1
    """"""

class ModuleBannerType(_ModuleBannerType, metaclass=_ModuleBannerTypeEnumTypeWrapper):
    """动态列表-通栏类型"""

module_banner_type_none: ModuleBannerType.ValueType  # 0
""""""
module_banner_type_user: ModuleBannerType.ValueType  # 1
""""""
global___ModuleBannerType = ModuleBannerType

class _ModuleDynamicType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModuleDynamicTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModuleDynamicType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    mdl_dyn_archive: _ModuleDynamicType.ValueType  # 0
    """稿件"""
    mdl_dyn_pgc: _ModuleDynamicType.ValueType  # 1
    """pgc"""
    mdl_dyn_cour_season: _ModuleDynamicType.ValueType  # 2
    """付费课程-系列"""
    mdl_dyn_cour_batch: _ModuleDynamicType.ValueType  # 3
    """付费课程-批次"""
    mdl_dyn_forward: _ModuleDynamicType.ValueType  # 4
    """转发卡"""
    mdl_dyn_draw: _ModuleDynamicType.ValueType  # 5
    """图文"""
    mdl_dyn_article: _ModuleDynamicType.ValueType  # 6
    """专栏"""
    mdl_dyn_music: _ModuleDynamicType.ValueType  # 7
    """音频"""
    mdl_dyn_common: _ModuleDynamicType.ValueType  # 8
    """通用卡方"""
    mdl_dyn_live: _ModuleDynamicType.ValueType  # 9
    """直播卡"""
    mdl_dyn_medialist: _ModuleDynamicType.ValueType  # 10
    """播单"""
    mdl_dyn_applet: _ModuleDynamicType.ValueType  # 11
    """小程序卡"""
    mdl_dyn_subscription: _ModuleDynamicType.ValueType  # 12
    """订阅卡"""
    mdl_dyn_live_rcmd: _ModuleDynamicType.ValueType  # 13
    """直播推荐卡"""
    mdl_dyn_ugc_season: _ModuleDynamicType.ValueType  # 14
    """UGC合集"""
    mdl_dyn_subscription_new: _ModuleDynamicType.ValueType  # 15
    """订阅卡"""

class ModuleDynamicType(_ModuleDynamicType, metaclass=_ModuleDynamicTypeEnumTypeWrapper):
    """动态详情模块类型"""

mdl_dyn_archive: ModuleDynamicType.ValueType  # 0
"""稿件"""
mdl_dyn_pgc: ModuleDynamicType.ValueType  # 1
"""pgc"""
mdl_dyn_cour_season: ModuleDynamicType.ValueType  # 2
"""付费课程-系列"""
mdl_dyn_cour_batch: ModuleDynamicType.ValueType  # 3
"""付费课程-批次"""
mdl_dyn_forward: ModuleDynamicType.ValueType  # 4
"""转发卡"""
mdl_dyn_draw: ModuleDynamicType.ValueType  # 5
"""图文"""
mdl_dyn_article: ModuleDynamicType.ValueType  # 6
"""专栏"""
mdl_dyn_music: ModuleDynamicType.ValueType  # 7
"""音频"""
mdl_dyn_common: ModuleDynamicType.ValueType  # 8
"""通用卡方"""
mdl_dyn_live: ModuleDynamicType.ValueType  # 9
"""直播卡"""
mdl_dyn_medialist: ModuleDynamicType.ValueType  # 10
"""播单"""
mdl_dyn_applet: ModuleDynamicType.ValueType  # 11
"""小程序卡"""
mdl_dyn_subscription: ModuleDynamicType.ValueType  # 12
"""订阅卡"""
mdl_dyn_live_rcmd: ModuleDynamicType.ValueType  # 13
"""直播推荐卡"""
mdl_dyn_ugc_season: ModuleDynamicType.ValueType  # 14
"""UGC合集"""
mdl_dyn_subscription_new: ModuleDynamicType.ValueType  # 15
"""订阅卡"""
global___ModuleDynamicType = ModuleDynamicType

class _Refresh:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RefreshEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Refresh.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    refresh_new: _Refresh.ValueType  # 0
    """刷新列表"""
    refresh_history: _Refresh.ValueType  # 1
    """请求历史"""

class Refresh(_Refresh, metaclass=_RefreshEnumTypeWrapper):
    """刷新方式"""

refresh_new: Refresh.ValueType  # 0
"""刷新列表"""
refresh_history: Refresh.ValueType  # 1
"""请求历史"""
global___Refresh = Refresh

class _RelationStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RelationStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RelationStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    relation_status_none: _RelationStatus.ValueType  # 0
    """1-未关注 2-关注 3-被关注 4-互相关注 5-特别关注"""
    relation_status_nofollow: _RelationStatus.ValueType  # 1
    relation_status_follow: _RelationStatus.ValueType  # 2
    relation_status_followed: _RelationStatus.ValueType  # 3
    relation_status_mutual_concern: _RelationStatus.ValueType  # 4
    relation_status_special: _RelationStatus.ValueType  # 5

class RelationStatus(_RelationStatus, metaclass=_RelationStatusEnumTypeWrapper):
    """关注关系 枚举"""

relation_status_none: RelationStatus.ValueType  # 0
"""1-未关注 2-关注 3-被关注 4-互相关注 5-特别关注"""
relation_status_nofollow: RelationStatus.ValueType  # 1
relation_status_follow: RelationStatus.ValueType  # 2
relation_status_followed: RelationStatus.ValueType  # 3
relation_status_mutual_concern: RelationStatus.ValueType  # 4
relation_status_special: RelationStatus.ValueType  # 5
global___RelationStatus = RelationStatus

class _ReserveType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReserveTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    reserve_none: _ReserveType.ValueType  # 0
    """占位"""
    reserve_recall: _ReserveType.ValueType  # 1
    """预约召回"""

class ReserveType(_ReserveType, metaclass=_ReserveTypeEnumTypeWrapper):
    """"""

reserve_none: ReserveType.ValueType  # 0
"""占位"""
reserve_recall: ReserveType.ValueType  # 1
"""预约召回"""
global___ReserveType = ReserveType

class _ThreePointAttentionStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThreePointAttentionStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThreePointAttentionStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    tp_not_attention: _ThreePointAttentionStatus.ValueType  # 0
    """"""
    tp_attention: _ThreePointAttentionStatus.ValueType  # 1
    """"""

class ThreePointAttentionStatus(_ThreePointAttentionStatus, metaclass=_ThreePointAttentionStatusEnumTypeWrapper):
    """枚举-三点关注状态"""

tp_not_attention: ThreePointAttentionStatus.ValueType  # 0
""""""
tp_attention: ThreePointAttentionStatus.ValueType  # 1
""""""
global___ThreePointAttentionStatus = ThreePointAttentionStatus

class _ThreePointType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThreePointTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThreePointType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    tp_none: _ThreePointType.ValueType  # 0
    """占位"""
    background: _ThreePointType.ValueType  # 1
    """使用此背景"""
    auto_play: _ThreePointType.ValueType  # 2
    """自动播放"""
    share: _ThreePointType.ValueType  # 3
    """分享"""
    wait: _ThreePointType.ValueType  # 4
    """稍后再播"""
    attention: _ThreePointType.ValueType  # 5
    """关注"""
    report: _ThreePointType.ValueType  # 6
    """举报"""
    delete: _ThreePointType.ValueType  # 7
    """删除"""
    dislike: _ThreePointType.ValueType  # 8
    """不感兴趣"""
    favorite: _ThreePointType.ValueType  # 9
    """收藏"""

class ThreePointType(_ThreePointType, metaclass=_ThreePointTypeEnumTypeWrapper):
    """三点类型"""

tp_none: ThreePointType.ValueType  # 0
"""占位"""
background: ThreePointType.ValueType  # 1
"""使用此背景"""
auto_play: ThreePointType.ValueType  # 2
"""自动播放"""
share: ThreePointType.ValueType  # 3
"""分享"""
wait: ThreePointType.ValueType  # 4
"""稍后再播"""
attention: ThreePointType.ValueType  # 5
"""关注"""
report: ThreePointType.ValueType  # 6
"""举报"""
delete: ThreePointType.ValueType  # 7
"""删除"""
dislike: ThreePointType.ValueType  # 8
"""不感兴趣"""
favorite: ThreePointType.ValueType  # 9
"""收藏"""
global___ThreePointType = ThreePointType

class _ThumbType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThumbTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThumbType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    cancel: _ThumbType.ValueType  # 0
    """"""
    thumb: _ThumbType.ValueType  # 1
    """"""

class ThumbType(_ThumbType, metaclass=_ThumbTypeEnumTypeWrapper):
    """"""

cancel: ThumbType.ValueType  # 0
""""""
thumb: ThumbType.ValueType  # 1
""""""
global___ThumbType = ThumbType

class _UserItemType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserItemTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserItemType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    user_item_type_none: _UserItemType.ValueType  # 0
    """"""
    user_item_type_live: _UserItemType.ValueType  # 1
    """"""
    user_item_type_live_custom: _UserItemType.ValueType  # 2
    """"""
    user_item_type_normal: _UserItemType.ValueType  # 3
    """"""
    user_item_type_extend: _UserItemType.ValueType  # 4
    """"""

class UserItemType(_UserItemType, metaclass=_UserItemTypeEnumTypeWrapper):
    """用户类型"""

user_item_type_none: UserItemType.ValueType  # 0
""""""
user_item_type_live: UserItemType.ValueType  # 1
""""""
user_item_type_live_custom: UserItemType.ValueType  # 2
""""""
user_item_type_normal: UserItemType.ValueType  # 3
""""""
user_item_type_extend: UserItemType.ValueType  # 4
""""""
global___UserItemType = UserItemType

class _VideoSubType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoSubTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoSubType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VideoSubTypeNone: _VideoSubType.ValueType  # 0
    """没有子类型"""
    VideoSubTypeBangumi: _VideoSubType.ValueType  # 1
    """番剧"""
    VideoSubTypeMovie: _VideoSubType.ValueType  # 2
    """电影"""
    VideoSubTypeDocumentary: _VideoSubType.ValueType  # 3
    """纪录片"""
    VideoSubTypeDomestic: _VideoSubType.ValueType  # 4
    """国创"""
    VideoSubTypeTeleplay: _VideoSubType.ValueType  # 5
    """电视剧"""

class VideoSubType(_VideoSubType, metaclass=_VideoSubTypeEnumTypeWrapper):
    """番剧类型"""

VideoSubTypeNone: VideoSubType.ValueType  # 0
"""没有子类型"""
VideoSubTypeBangumi: VideoSubType.ValueType  # 1
"""番剧"""
VideoSubTypeMovie: VideoSubType.ValueType  # 2
"""电影"""
VideoSubTypeDocumentary: VideoSubType.ValueType  # 3
"""纪录片"""
VideoSubTypeDomestic: VideoSubType.ValueType  # 4
"""国创"""
VideoSubTypeTeleplay: VideoSubType.ValueType  # 5
"""电视剧"""
global___VideoSubType = VideoSubType

class _VideoType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    video_type_general: _VideoType.ValueType  # 0
    """普通视频"""
    video_type_dynamic: _VideoType.ValueType  # 1
    """动态视频"""
    video_type_playback: _VideoType.ValueType  # 2
    """直播回放视频"""

class VideoType(_VideoType, metaclass=_VideoTypeEnumTypeWrapper):
    """视频类型"""

video_type_general: VideoType.ValueType  # 0
"""普通视频"""
video_type_dynamic: VideoType.ValueType  # 1
"""动态视频"""
video_type_playback: VideoType.ValueType  # 2
"""直播回放视频"""
global___VideoType = VideoType

class _VoteStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VoteStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VoteStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    normal: _VoteStatus.ValueType  # 0
    """正常"""
    anonymous: _VoteStatus.ValueType  # 1
    """匿名"""

class VoteStatus(_VoteStatus, metaclass=_VoteStatusEnumTypeWrapper):
    """状态"""

normal: VoteStatus.ValueType  # 0
"""正常"""
anonymous: VoteStatus.ValueType  # 1
"""匿名"""
global___VoteStatus = VoteStatus

class _WeightType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WeightTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WeightType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    weight_none: _WeightType.ValueType  # 0
    """默认 占位"""
    weight_dislike: _WeightType.ValueType  # 1
    """不感兴趣"""
    weight_jump: _WeightType.ValueType  # 2
    """跳链"""

class WeightType(_WeightType, metaclass=_WeightTypeEnumTypeWrapper):
    """枚举-提权类型"""

weight_none: WeightType.ValueType  # 0
"""默认 占位"""
weight_dislike: WeightType.ValueType  # 1
"""不感兴趣"""
weight_jump: WeightType.ValueType  # 2
"""跳链"""
global___WeightType = WeightType

@typing_extensions.final
class AdParam(google.protobuf.message.Message):
    """综合页请求广告所需字段，由客户端-网关透传"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AD_EXTRA_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    ad_extra: builtins.str
    """综合页请求广告所需字段，由客户端-网关透传"""
    request_id: builtins.str
    """request_id"""
    def __init__(
        self,
        *,
        ad_extra: builtins.str = ...,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra", b"ad_extra", "request_id", b"request_id"]) -> None: ...

global___AdParam = AdParam

@typing_extensions.final
class AdditionCommon(google.protobuf.message.Message):
    """动态-附加卡-通用卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEAD_TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    HEAD_ICON_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    head_text: builtins.str
    """头部说明文案"""
    title: builtins.str
    """标题"""
    image_url: builtins.str
    """展示图"""
    desc_text_1: builtins.str
    """描述文字1"""
    desc_text_2: builtins.str
    """描述文字2"""
    url: builtins.str
    """点击跳转链接"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    head_icon: builtins.str
    """头部icon"""
    style: global___ImageStyle.ValueType
    """style"""
    type: builtins.str
    """动态本身的类型 type"""
    card_type: builtins.str
    """附加卡类型
    ogv manga
    """
    def __init__(
        self,
        *,
        head_text: builtins.str = ...,
        title: builtins.str = ...,
        image_url: builtins.str = ...,
        desc_text_1: builtins.str = ...,
        desc_text_2: builtins.str = ...,
        url: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        head_icon: builtins.str = ...,
        style: global___ImageStyle.ValueType = ...,
        type: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "card_type", b"card_type", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2", "head_icon", b"head_icon", "head_text", b"head_text", "image_url", b"image_url", "style", b"style", "title", b"title", "type", b"type", "url", b"url"]) -> None: ...

global___AdditionCommon = AdditionCommon

@typing_extensions.final
class AdditionEsport(google.protobuf.message.Message):
    """动态-附加卡-电竞卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_FIELD_NUMBER: builtins.int
    ADDITION_ESPORT_MOBA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    style: global___EspaceStyle.ValueType
    """电竞类型"""
    @property
    def addition_esport_moba(self) -> global___AdditionEsportMoba:
        """moba类"""
    type: builtins.str
    """动态本身的类型 type"""
    card_type: builtins.str
    """附加卡类型
    ogv manga
    """
    def __init__(
        self,
        *,
        style: global___EspaceStyle.ValueType = ...,
        addition_esport_moba: global___AdditionEsportMoba | None = ...,
        type: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addition_esport_moba", b"addition_esport_moba", "item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_esport_moba", b"addition_esport_moba", "card_type", b"card_type", "item", b"item", "style", b"style", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["addition_esport_moba"] | None: ...

global___AdditionEsport = AdditionEsport

@typing_extensions.final
class AdditionEsportMoba(google.protobuf.message.Message):
    """动态-附加卡-电竞卡-moba类"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEAD_TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    MATCH_TEAM_FIELD_NUMBER: builtins.int
    ADDITION_ESPORT_MOBA_STATUS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    head_text: builtins.str
    """头部说明文案"""
    title: builtins.str
    """标题"""
    @property
    def match_team(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchTeam]:
        """战队列表"""
    @property
    def addition_esport_moba_status(self) -> global___AdditionEsportMobaStatus:
        """比赛信息"""
    uri: builtins.str
    """卡片跳转"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    sub_title: builtins.str
    """副标题"""
    type: builtins.str
    """动态本身的类型 type"""
    card_type: builtins.str
    """附加卡类型"""
    def __init__(
        self,
        *,
        head_text: builtins.str = ...,
        title: builtins.str = ...,
        match_team: collections.abc.Iterable[global___MatchTeam] | None = ...,
        addition_esport_moba_status: global___AdditionEsportMobaStatus | None = ...,
        uri: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        sub_title: builtins.str = ...,
        type: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addition_esport_moba_status", b"addition_esport_moba_status", "button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_esport_moba_status", b"addition_esport_moba_status", "button", b"button", "card_type", b"card_type", "head_text", b"head_text", "match_team", b"match_team", "sub_title", b"sub_title", "title", b"title", "type", b"type", "uri", b"uri"]) -> None: ...

global___AdditionEsportMoba = AdditionEsportMoba

@typing_extensions.final
class AdditionEsportMobaStatus(google.protobuf.message.Message):
    """动态-附加卡-电竞卡-moba类-比赛信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITION_ESPORT_MOBA_STATUS_DESC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    NIGHT_COLOR_FIELD_NUMBER: builtins.int
    @property
    def addition_esport_moba_status_desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionEsportMobaStatusDesc]:
        """文案类"""
    title: builtins.str
    """比赛状态文案"""
    status: builtins.int
    """比赛状态状态"""
    color: builtins.str
    """日间色值"""
    night_color: builtins.str
    """夜间色值"""
    def __init__(
        self,
        *,
        addition_esport_moba_status_desc: collections.abc.Iterable[global___AdditionEsportMobaStatusDesc] | None = ...,
        title: builtins.str = ...,
        status: builtins.int = ...,
        color: builtins.str = ...,
        night_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_esport_moba_status_desc", b"addition_esport_moba_status_desc", "color", b"color", "night_color", b"night_color", "status", b"status", "title", b"title"]) -> None: ...

global___AdditionEsportMobaStatus = AdditionEsportMobaStatus

@typing_extensions.final
class AdditionEsportMobaStatusDesc(google.protobuf.message.Message):
    """动态-附加卡-电竞卡-moba类-比赛信息-文案类"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    NIGHT_COLOR_FIELD_NUMBER: builtins.int
    title: builtins.str
    """文案"""
    color: builtins.str
    """日间色值"""
    night_color: builtins.str
    """夜间色值"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        color: builtins.str = ...,
        night_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "night_color", b"night_color", "title", b"title"]) -> None: ...

global___AdditionEsportMobaStatusDesc = AdditionEsportMobaStatusDesc

@typing_extensions.final
class AdditionGoods(google.protobuf.message.Message):
    """动态-附加卡-商品卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RCMD_DESC_FIELD_NUMBER: builtins.int
    GOODS_ITEMS_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    rcmd_desc: builtins.str
    """推荐文案"""
    @property
    def goods_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GoodsItem]:
        """商品信息"""
    card_type: builtins.str
    """附加卡类型"""
    icon: builtins.str
    """头部icon"""
    uri: builtins.str
    """商品附加卡整卡跳转"""
    source_type: builtins.int
    """商品类型
    1:淘宝 2:会员购，注：实际是获取的goods_items里面的第一个source_type
    """
    def __init__(
        self,
        *,
        rcmd_desc: builtins.str = ...,
        goods_items: collections.abc.Iterable[global___GoodsItem] | None = ...,
        card_type: builtins.str = ...,
        icon: builtins.str = ...,
        uri: builtins.str = ...,
        source_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type", b"card_type", "goods_items", b"goods_items", "icon", b"icon", "rcmd_desc", b"rcmd_desc", "source_type", b"source_type", "uri", b"uri"]) -> None: ...

global___AdditionGoods = AdditionGoods

@typing_extensions.final
class AdditionUP(google.protobuf.message.Message):
    """up主预约发布卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    RESERVE_TOTAL_FIELD_NUMBER: builtins.int
    ACT_SKIN_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    @property
    def desc_text_1(self) -> global___HighlightText:
        """高亮文本，描述文字1"""
    desc_text_2: builtins.str
    """描述文字2"""
    url: builtins.str
    """点击跳转链接"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    card_type: builtins.str
    """附加卡类型"""
    reserve_total: builtins.int
    """预约人数(用于预约人数变化)"""
    @property
    def act_skin(self) -> global___AdditionalActSkin:
        """活动皮肤"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc_text_1: global___HighlightText | None = ...,
        desc_text_2: builtins.str = ...,
        url: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        card_type: builtins.str = ...,
        reserve_total: builtins.int = ...,
        act_skin: global___AdditionalActSkin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["act_skin", b"act_skin", "button", b"button", "desc_text_1", b"desc_text_1"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_skin", b"act_skin", "button", b"button", "card_type", b"card_type", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2", "reserve_total", b"reserve_total", "title", b"title", "url", b"url"]) -> None: ...

global___AdditionUP = AdditionUP

@typing_extensions.final
class AdditionUgc(google.protobuf.message.Message):
    """动态-附加卡-UGC视频附加卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEAD_TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    LINE_FEED_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    head_text: builtins.str
    """说明文案"""
    title: builtins.str
    """稿件标题"""
    cover: builtins.str
    """封面"""
    desc_text_1: builtins.str
    """描述文字1"""
    desc_text_2: builtins.str
    """描述文字2"""
    uri: builtins.str
    """接秒开"""
    duration: builtins.str
    """时长"""
    line_feed: builtins.bool
    """标题支持换行-标题支持单行和双行，本期不支持填充up昵称，支持双行展示，字段默认为true"""
    card_type: builtins.str
    """附加卡类型"""
    def __init__(
        self,
        *,
        head_text: builtins.str = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        desc_text_1: builtins.str = ...,
        desc_text_2: builtins.str = ...,
        uri: builtins.str = ...,
        duration: builtins.str = ...,
        line_feed: builtins.bool = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type", b"card_type", "cover", b"cover", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2", "duration", b"duration", "head_text", b"head_text", "line_feed", b"line_feed", "title", b"title", "uri", b"uri"]) -> None: ...

global___AdditionUgc = AdditionUgc

@typing_extensions.final
class AdditionVote(google.protobuf.message.Message):
    """动态-附加卡-投票"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    BUTTON_TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    image_url: builtins.str
    """封面图"""
    title: builtins.str
    """标题"""
    text_1: builtins.str
    """展示项1"""
    button_text: builtins.str
    """button文案"""
    url: builtins.str
    """点击跳转链接"""
    def __init__(
        self,
        *,
        image_url: builtins.str = ...,
        title: builtins.str = ...,
        text_1: builtins.str = ...,
        button_text: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_text", b"button_text", "image_url", b"image_url", "text_1", b"text_1", "title", b"title", "url", b"url"]) -> None: ...

global___AdditionVote = AdditionVote

@typing_extensions.final
class AdditionVote2(google.protobuf.message.Message):
    """动态模块-投票"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITION_VOTE_TYPE_FIELD_NUMBER: builtins.int
    VOTE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    DEADLINE_FIELD_NUMBER: builtins.int
    OPEN_TEXT_FIELD_NUMBER: builtins.int
    CLOSE_TEXT_FIELD_NUMBER: builtins.int
    VOTED_TEXT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ADDITION_VOTE_WORD_FIELD_NUMBER: builtins.int
    ADDITION_VOTE_PIC_FIELD_NUMBER: builtins.int
    ADDITION_VOTE_DEFAULE_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    TIPS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    IS_VOTED_FIELD_NUMBER: builtins.int
    CHOICE_CNT_FIELD_NUMBER: builtins.int
    DEFAULE_SELECT_SHARE_FIELD_NUMBER: builtins.int
    addition_vote_type: global___AdditionVoteType.ValueType
    """投票类型"""
    vote_id: builtins.int
    """投票ID"""
    title: builtins.str
    """标题"""
    label: builtins.str
    """已过期： xxx人参与· 投票已过期。button 展示去查看
    未过期： xxx人参与· 剩xx天xx时xx分。button展示去投票
    """
    deadline: builtins.int
    """剩余时间"""
    open_text: builtins.str
    """生效文案"""
    close_text: builtins.str
    """过期文案"""
    voted_text: builtins.str
    """已投票"""
    state: global___AdditionVoteState.ValueType
    """投票状态"""
    @property
    def addition_vote_word(self) -> global___AdditionVoteWord:
        """"""
    @property
    def addition_vote_pic(self) -> global___AdditionVotePic:
        """"""
    @property
    def addition_vote_defaule(self) -> global___AdditionVoteDefaule:
        """"""
    biz_type: builtins.int
    """业务类型
    0:动态投票 1:话题h5组件
    """
    total: builtins.int
    """投票总人数"""
    card_type: builtins.str
    """附加卡类型"""
    tips: builtins.str
    """异常提示"""
    uri: builtins.str
    """跳转地址"""
    is_voted: builtins.bool
    """是否投票"""
    choice_cnt: builtins.int
    """投票最多多选个数，单选为1"""
    defaule_select_share: builtins.bool
    """是否默认选中分享到动态"""
    def __init__(
        self,
        *,
        addition_vote_type: global___AdditionVoteType.ValueType = ...,
        vote_id: builtins.int = ...,
        title: builtins.str = ...,
        label: builtins.str = ...,
        deadline: builtins.int = ...,
        open_text: builtins.str = ...,
        close_text: builtins.str = ...,
        voted_text: builtins.str = ...,
        state: global___AdditionVoteState.ValueType = ...,
        addition_vote_word: global___AdditionVoteWord | None = ...,
        addition_vote_pic: global___AdditionVotePic | None = ...,
        addition_vote_defaule: global___AdditionVoteDefaule | None = ...,
        biz_type: builtins.int = ...,
        total: builtins.int = ...,
        card_type: builtins.str = ...,
        tips: builtins.str = ...,
        uri: builtins.str = ...,
        is_voted: builtins.bool = ...,
        choice_cnt: builtins.int = ...,
        defaule_select_share: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addition_vote_defaule", b"addition_vote_defaule", "addition_vote_pic", b"addition_vote_pic", "addition_vote_word", b"addition_vote_word", "item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_vote_defaule", b"addition_vote_defaule", "addition_vote_pic", b"addition_vote_pic", "addition_vote_type", b"addition_vote_type", "addition_vote_word", b"addition_vote_word", "biz_type", b"biz_type", "card_type", b"card_type", "choice_cnt", b"choice_cnt", "close_text", b"close_text", "deadline", b"deadline", "defaule_select_share", b"defaule_select_share", "is_voted", b"is_voted", "item", b"item", "label", b"label", "open_text", b"open_text", "state", b"state", "tips", b"tips", "title", b"title", "total", b"total", "uri", b"uri", "vote_id", b"vote_id", "voted_text", b"voted_text"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["addition_vote_word", "addition_vote_pic", "addition_vote_defaule"] | None: ...

global___AdditionVote2 = AdditionVote2

@typing_extensions.final
class AdditionVoteDefaule(google.protobuf.message.Message):
    """外露投票"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    @property
    def cover(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """图片 多张"""
    def __init__(
        self,
        *,
        cover: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover"]) -> None: ...

global___AdditionVoteDefaule = AdditionVoteDefaule

@typing_extensions.final
class AdditionVotePic(google.protobuf.message.Message):
    """外露图片类型"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionVotePicItem]:
        """图片投票详情"""
    def __init__(
        self,
        *,
        item: collections.abc.Iterable[global___AdditionVotePicItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___AdditionVotePic = AdditionVotePic

@typing_extensions.final
class AdditionVotePicItem(google.protobuf.message.Message):
    """图片投票详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPT_IDX_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    IS_VOTE_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    PERSENT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    IS_MAX_OPTION_FIELD_NUMBER: builtins.int
    opt_idx: builtins.int
    """选项索引，从1开始"""
    cover: builtins.str
    """图片"""
    is_vote: builtins.bool
    """选中状态"""
    total: builtins.int
    """人数"""
    persent: builtins.float
    """占比"""
    title: builtins.str
    """标题文案"""
    is_max_option: builtins.bool
    """是否投票人数最多的选项"""
    def __init__(
        self,
        *,
        opt_idx: builtins.int = ...,
        cover: builtins.str = ...,
        is_vote: builtins.bool = ...,
        total: builtins.int = ...,
        persent: builtins.float = ...,
        title: builtins.str = ...,
        is_max_option: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "is_max_option", b"is_max_option", "is_vote", b"is_vote", "opt_idx", b"opt_idx", "persent", b"persent", "title", b"title", "total", b"total"]) -> None: ...

global___AdditionVotePicItem = AdditionVotePicItem

@typing_extensions.final
class AdditionVoteWord(google.protobuf.message.Message):
    """外露文字类型"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionVoteWordItem]:
        """外露文字投票详情"""
    def __init__(
        self,
        *,
        item: collections.abc.Iterable[global___AdditionVoteWordItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___AdditionVoteWord = AdditionVoteWord

@typing_extensions.final
class AdditionVoteWordItem(google.protobuf.message.Message):
    """外露文字投票详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPT_IDX_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    IS_VOTE_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    PERSENT_FIELD_NUMBER: builtins.int
    IS_MAX_OPTION_FIELD_NUMBER: builtins.int
    opt_idx: builtins.int
    """选项索引，从1开始"""
    title: builtins.str
    """文案"""
    is_vote: builtins.bool
    """选中状态"""
    total: builtins.int
    """人数"""
    persent: builtins.float
    """占比"""
    is_max_option: builtins.bool
    """是否投票人数最多的选项"""
    def __init__(
        self,
        *,
        opt_idx: builtins.int = ...,
        title: builtins.str = ...,
        is_vote: builtins.bool = ...,
        total: builtins.int = ...,
        persent: builtins.float = ...,
        is_max_option: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_max_option", b"is_max_option", "is_vote", b"is_vote", "opt_idx", b"opt_idx", "persent", b"persent", "title", b"title", "total", b"total"]) -> None: ...

global___AdditionVoteWordItem = AdditionVoteWordItem

@typing_extensions.final
class AdditionalActSkin(google.protobuf.message.Message):
    """活动皮肤"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SVGA_FIELD_NUMBER: builtins.int
    LAST_IMAGE_FIELD_NUMBER: builtins.int
    PLAY_TIMES_FIELD_NUMBER: builtins.int
    svga: builtins.str
    """动画SVGA资源"""
    last_image: builtins.str
    """动画SVGA最后一帧图片资源"""
    play_times: builtins.int
    """动画播放次数"""
    def __init__(
        self,
        *,
        svga: builtins.str = ...,
        last_image: builtins.str = ...,
        play_times: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_image", b"last_image", "play_times", b"play_times", "svga", b"svga"]) -> None: ...

global___AdditionalActSkin = AdditionalActSkin

@typing_extensions.final
class AdditionalButton(google.protobuf.message.Message):
    """动态-附加卡-按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    JUMP_STYLE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    UNCHECK_FIELD_NUMBER: builtins.int
    CHECK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CLICK_TYPE_FIELD_NUMBER: builtins.int
    type: global___AddButtonType.ValueType
    """按钮类型"""
    @property
    def jump_style(self) -> global___AdditionalButtonStyle:
        """jump-跳转样式"""
    jump_url: builtins.str
    """jump-跳转链接"""
    @property
    def uncheck(self) -> global___AdditionalButtonStyle:
        """button-未点样式"""
    @property
    def check(self) -> global___AdditionalButtonStyle:
        """button-已点样式"""
    status: global___AdditionalButtonStatus.ValueType
    """button-当前状态"""
    click_type: global___AdditionalButtonClickType.ValueType
    """按钮点击样式"""
    def __init__(
        self,
        *,
        type: global___AddButtonType.ValueType = ...,
        jump_style: global___AdditionalButtonStyle | None = ...,
        jump_url: builtins.str = ...,
        uncheck: global___AdditionalButtonStyle | None = ...,
        check: global___AdditionalButtonStyle | None = ...,
        status: global___AdditionalButtonStatus.ValueType = ...,
        click_type: global___AdditionalButtonClickType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["check", b"check", "jump_style", b"jump_style", "uncheck", b"uncheck"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check", b"check", "click_type", b"click_type", "jump_style", b"jump_style", "jump_url", b"jump_url", "status", b"status", "type", b"type", "uncheck", b"uncheck"]) -> None: ...

global___AdditionalButton = AdditionalButton

@typing_extensions.final
class AdditionalButtonInteractive(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POPUPS_FIELD_NUMBER: builtins.int
    CONFIRM_FIELD_NUMBER: builtins.int
    CANCEL_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    popups: builtins.str
    """是否弹窗"""
    confirm: builtins.str
    """弹窗确认文案"""
    cancel: builtins.str
    """弹窗取消文案"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        popups: builtins.str = ...,
        confirm: builtins.str = ...,
        cancel: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cancel", b"cancel", "confirm", b"confirm", "desc", b"desc", "popups", b"popups"]) -> None: ...

global___AdditionalButtonInteractive = AdditionalButtonInteractive

@typing_extensions.final
class AdditionalButtonStyle(google.protobuf.message.Message):
    """动态-附加卡-按钮样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    INTERACTIVE_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    DISABLE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    text: builtins.str
    """文案"""
    @property
    def interactive(self) -> global___AdditionalButtonInteractive:
        """按钮点击交互"""
    bg_style: global___AddButtonBgStyle.ValueType
    """当前按钮填充样式"""
    toast: builtins.str
    """toast文案, 当disable=1时有效"""
    disable: global___DisableState.ValueType
    """当前按钮样式,
    0:高亮 1:置灰(按钮不可点击)
    """
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
        interactive: global___AdditionalButtonInteractive | None = ...,
        bg_style: global___AddButtonBgStyle.ValueType = ...,
        toast: builtins.str = ...,
        disable: global___DisableState.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["interactive", b"interactive"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_style", b"bg_style", "disable", b"disable", "icon", b"icon", "interactive", b"interactive", "text", b"text", "toast", b"toast"]) -> None: ...

global___AdditionalButtonStyle = AdditionalButtonStyle

@typing_extensions.final
class AdditionalPGC(google.protobuf.message.Message):
    """动态-附加卡-番剧卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEAD_TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    HEAD_ICON_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    head_text: builtins.str
    """头部说明文案"""
    title: builtins.str
    """标题"""
    image_url: builtins.str
    """展示图"""
    desc_text_1: builtins.str
    """描述文字1"""
    desc_text_2: builtins.str
    """描述文字2"""
    url: builtins.str
    """点击跳转链接"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    head_icon: builtins.str
    """头部icon"""
    style: global___ImageStyle.ValueType
    """style"""
    type: builtins.str
    """动态本身的类型 type"""
    def __init__(
        self,
        *,
        head_text: builtins.str = ...,
        title: builtins.str = ...,
        image_url: builtins.str = ...,
        desc_text_1: builtins.str = ...,
        desc_text_2: builtins.str = ...,
        url: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        head_icon: builtins.str = ...,
        style: global___ImageStyle.ValueType = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2", "head_icon", b"head_icon", "head_text", b"head_text", "image_url", b"image_url", "style", b"style", "title", b"title", "type", b"type", "url", b"url"]) -> None: ...

global___AdditionalPGC = AdditionalPGC

@typing_extensions.final
class CardVideoDynList(google.protobuf.message.Message):
    """动态卡片列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    UPDATE_NUM_FIELD_NUMBER: builtins.int
    HISTORY_OFFSET_FIELD_NUMBER: builtins.int
    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    update_num: builtins.int
    """更新的动态数"""
    history_offset: builtins.str
    """历史偏移"""
    update_baseline: builtins.str
    """更新基础信息"""
    has_more: builtins.bool
    """是否还有更多数据"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        update_num: builtins.int = ...,
        history_offset: builtins.str = ...,
        update_baseline: builtins.str = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "history_offset", b"history_offset", "list", b"list", "update_baseline", b"update_baseline", "update_num", b"update_num"]) -> None: ...

global___CardVideoDynList = CardVideoDynList

@typing_extensions.final
class CardVideoFollowList(google.protobuf.message.Message):
    """视频页-我的追番"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_ALL_LINK_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    view_all_link: builtins.str
    """查看全部(跳转链接)"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FollowListItem]:
        """追番列表"""
    def __init__(
        self,
        *,
        view_all_link: builtins.str = ...,
        list: collections.abc.Iterable[global___FollowListItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list", "view_all_link", b"view_all_link"]) -> None: ...

global___CardVideoFollowList = CardVideoFollowList

@typing_extensions.final
class CardVideoUpList(google.protobuf.message.Message):
    """视频页-最近访问"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    SHOW_LIVE_NUM_FIELD_NUMBER: builtins.int
    MORE_LABEL_FIELD_NUMBER: builtins.int
    TITLE_SWITCH_FIELD_NUMBER: builtins.int
    SHOW_MORE_LABEL_FIELD_NUMBER: builtins.int
    SHOW_IN_PERSONAL_FIELD_NUMBER: builtins.int
    SHOW_MORE_BUTTON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题展示文案"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpListItem]:
        """up主列表"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    show_live_num: builtins.int
    """直播数"""
    @property
    def more_label(self) -> global___UpListMoreLabel:
        """跳转label"""
    title_switch: builtins.int
    """标题开关(综合页)"""
    show_more_label: builtins.bool
    """是否展示右上角查看更多label"""
    show_in_personal: builtins.bool
    """是否在快速消费页查看更多按钮"""
    show_more_button: builtins.bool
    """是否展示右侧查看更多按钮"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        list: collections.abc.Iterable[global___UpListItem] | None = ...,
        footprint: builtins.str = ...,
        show_live_num: builtins.int = ...,
        more_label: global___UpListMoreLabel | None = ...,
        title_switch: builtins.int = ...,
        show_more_label: builtins.bool = ...,
        show_in_personal: builtins.bool = ...,
        show_more_button: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["more_label", b"more_label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "list", b"list", "more_label", b"more_label", "show_in_personal", b"show_in_personal", "show_live_num", b"show_live_num", "show_more_button", b"show_more_button", "show_more_label", b"show_more_label", "title", b"title", "title_switch", b"title_switch"]) -> None: ...

global___CardVideoUpList = CardVideoUpList

@typing_extensions.final
class CmtShowItem(google.protobuf.message.Message):
    """评论外露展示项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    UNAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""
    uname: builtins.str
    """用户昵称"""
    uri: builtins.str
    """点击跳转链接"""
    comment: builtins.str
    """评论内容"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        uname: builtins.str = ...,
        uri: builtins.str = ...,
        comment: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment", "uid", b"uid", "uname", b"uname", "uri", b"uri"]) -> None: ...

global___CmtShowItem = CmtShowItem

@typing_extensions.final
class DecoCardFan(google.protobuf.message.Message):
    """装扮卡片-粉丝勋章信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_FAN_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    NUMBER_STR_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    is_fan: builtins.int
    """是否是粉丝"""
    number: builtins.int
    """数量"""
    number_str: builtins.str
    """数量 str"""
    color: builtins.str
    """颜色"""
    def __init__(
        self,
        *,
        is_fan: builtins.int = ...,
        number: builtins.int = ...,
        number_str: builtins.str = ...,
        color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "is_fan", b"is_fan", "number", b"number", "number_str", b"number_str"]) -> None: ...

global___DecoCardFan = DecoCardFan

@typing_extensions.final
class DecorateCard(google.protobuf.message.Message):
    """装扮卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CARD_URL_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    FAN_FIELD_NUMBER: builtins.int
    id: builtins.int
    """装扮卡片id"""
    card_url: builtins.str
    """装扮卡片链接"""
    jump_url: builtins.str
    """装扮卡片点击跳转链接"""
    @property
    def fan(self) -> global___DecoCardFan:
        """粉丝样式"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        card_url: builtins.str = ...,
        jump_url: builtins.str = ...,
        fan: global___DecoCardFan | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fan", b"fan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_url", b"card_url", "fan", b"fan", "id", b"id", "jump_url", b"jump_url"]) -> None: ...

global___DecorateCard = DecorateCard

@typing_extensions.final
class Description(google.protobuf.message.Message):
    """文本描述"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    EMOJI_TYPE_FIELD_NUMBER: builtins.int
    GOODS_TYPE_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    ICON_NAME_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    GOODS_FIELD_NUMBER: builtins.int
    ORIG_TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文本内容"""
    type: global___DescType.ValueType
    """文本类型"""
    uri: builtins.str
    """点击跳转链接"""
    emoji_type: global___EmojiType.ValueType
    """emoji类型"""
    goods_type: builtins.str
    """商品类型"""
    icon_url: builtins.str
    """前置Icon"""
    icon_name: builtins.str
    """icon_name"""
    rid: builtins.str
    """资源ID"""
    @property
    def goods(self) -> global___ModuleDescGoods:
        """商品卡特殊字段"""
    orig_text: builtins.str
    """文本原始文案"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        type: global___DescType.ValueType = ...,
        uri: builtins.str = ...,
        emoji_type: global___EmojiType.ValueType = ...,
        goods_type: builtins.str = ...,
        icon_url: builtins.str = ...,
        icon_name: builtins.str = ...,
        rid: builtins.str = ...,
        goods: global___ModuleDescGoods | None = ...,
        orig_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["goods", b"goods"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["emoji_type", b"emoji_type", "goods", b"goods", "goods_type", b"goods_type", "icon_name", b"icon_name", "icon_url", b"icon_url", "orig_text", b"orig_text", "rid", b"rid", "text", b"text", "type", b"type", "uri", b"uri"]) -> None: ...

global___Description = Description

@typing_extensions.final
class Dimension(google.protobuf.message.Message):
    """尺寸信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    height: builtins.int
    """"""
    width: builtins.int
    """"""
    rotate: builtins.int
    """"""
    def __init__(
        self,
        *,
        height: builtins.int = ...,
        width: builtins.int = ...,
        rotate: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "rotate", b"rotate", "width", b"width"]) -> None: ...

global___Dimension = Dimension

@typing_extensions.final
class DynAdditionCommonFollowReply(google.protobuf.message.Message):
    """动态通用附加卡-follow/取消follow-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: global___AdditionalButtonStatus.ValueType
    """"""
    def __init__(
        self,
        *,
        status: global___AdditionalButtonStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___DynAdditionCommonFollowReply = DynAdditionCommonFollowReply

@typing_extensions.final
class DynAdditionCommonFollowReq(google.protobuf.message.Message):
    """动态通用附加卡-follow/取消follow-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DYN_ID_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    status: global___AdditionalButtonStatus.ValueType
    """"""
    dyn_id: builtins.str
    """"""
    card_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        status: global___AdditionalButtonStatus.ValueType = ...,
        dyn_id: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type", b"card_type", "dyn_id", b"dyn_id", "status", b"status"]) -> None: ...

global___DynAdditionCommonFollowReq = DynAdditionCommonFollowReq

@typing_extensions.final
class DynAllPersonalReply(google.protobuf.message.Message):
    """最近访问-个人feed流列表-返回"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    offset: builtins.str
    """偏移量"""
    has_more: builtins.bool
    """是否还有更多数据"""
    read_offset: builtins.str
    """已读进度"""
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        read_offset: builtins.str = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset", "read_offset", b"read_offset", "relation", b"relation"]) -> None: ...

global___DynAllPersonalReply = DynAllPersonalReply

@typing_extensions.final
class DynAllPersonalReq(google.protobuf.message.Message):
    """最近访问-个人feed流列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    IS_PRELOAD_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的 UID"""
    offset: builtins.str
    """偏移量 第一页可传空"""
    page: builtins.int
    """标明下拉几次"""
    is_preload: builtins.int
    """是否是预加载 默认是1；客户端预加载。1：是预加载，不更新已读进度，不会影响小红点；0：非预加载，更新已读进度"""
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    @property
    def player_args(self) -> global___PlayerArgs:
        """秒开用"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        offset: builtins.str = ...,
        page: builtins.int = ...,
        is_preload: builtins.int = ...,
        playurl_param: global___PlayurlParam | None = ...,
        local_time: builtins.int = ...,
        footprint: builtins.str = ...,
        player_args: global___PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args", "playurl_param", b"playurl_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "from", b"from", "host_uid", b"host_uid", "is_preload", b"is_preload", "local_time", b"local_time", "offset", b"offset", "page", b"page", "player_args", b"player_args", "playurl_param", b"playurl_param"]) -> None: ...

global___DynAllPersonalReq = DynAllPersonalReq

@typing_extensions.final
class DynAllReply(google.protobuf.message.Message):
    """动态综合页-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_LIST_FIELD_NUMBER: builtins.int
    UP_LIST_FIELD_NUMBER: builtins.int
    TOPIC_LIST_FIELD_NUMBER: builtins.int
    UNFOLLOW_FIELD_NUMBER: builtins.int
    @property
    def dynamic_list(self) -> global___DynamicList:
        """卡片列表"""
    @property
    def up_list(self) -> global___CardVideoUpList:
        """顶部up list"""
    @property
    def topic_list(self) -> global___TopicList:
        """话题广场"""
    @property
    def unfollow(self) -> global___Unfollow:
        """无关注推荐"""
    def __init__(
        self,
        *,
        dynamic_list: global___DynamicList | None = ...,
        up_list: global___CardVideoUpList | None = ...,
        topic_list: global___TopicList | None = ...,
        unfollow: global___Unfollow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list", "topic_list", b"topic_list", "unfollow", b"unfollow", "up_list", b"up_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list", "topic_list", b"topic_list", "unfollow", b"unfollow", "up_list", b"up_list"]) -> None: ...

global___DynAllReply = DynAllReply

@typing_extensions.final
class DynAllReq(google.protobuf.message.Message):
    """动态综合页-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    REFRESH_TYPE_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    ASSIST_BASELINE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    RCMD_UPS_PARAM_FIELD_NUMBER: builtins.int
    AD_PARAM_FIELD_NUMBER: builtins.int
    COLD_START_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    update_baseline: builtins.str
    """透传 update_baseline"""
    offset: builtins.str
    """透传 history_offset"""
    page: builtins.int
    """向下翻页数"""
    refresh_type: global___Refresh.ValueType
    """刷新方式 1向上刷新 2向下翻页"""
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    assist_baseline: builtins.str
    """综合页当前更新的最大值"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    @property
    def rcmd_ups_param(self) -> global___RcmdUPsParam:
        """推荐up主入参(new的时候传)"""
    @property
    def ad_param(self) -> global___AdParam:
        """广告参数"""
    cold_start: builtins.int
    """是否冷启"""
    @property
    def player_args(self) -> global___PlayerArgs:
        """秒开参数"""
    def __init__(
        self,
        *,
        update_baseline: builtins.str = ...,
        offset: builtins.str = ...,
        page: builtins.int = ...,
        refresh_type: global___Refresh.ValueType = ...,
        playurl_param: global___PlayurlParam | None = ...,
        assist_baseline: builtins.str = ...,
        local_time: builtins.int = ...,
        rcmd_ups_param: global___RcmdUPsParam | None = ...,
        ad_param: global___AdParam | None = ...,
        cold_start: builtins.int = ...,
        player_args: global___PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_param", b"ad_param", "player_args", b"player_args", "playurl_param", b"playurl_param", "rcmd_ups_param", b"rcmd_ups_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_param", b"ad_param", "assist_baseline", b"assist_baseline", "cold_start", b"cold_start", "from", b"from", "local_time", b"local_time", "offset", b"offset", "page", b"page", "player_args", b"player_args", "playurl_param", b"playurl_param", "rcmd_ups_param", b"rcmd_ups_param", "refresh_type", b"refresh_type", "update_baseline", b"update_baseline"]) -> None: ...

global___DynAllReq = DynAllReq

@typing_extensions.final
class DynAllUpdOffsetReq(google.protobuf.message.Message):
    """最近访问-标记已读-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的UID"""
    read_offset: builtins.str
    """用户已读进度"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        read_offset: builtins.str = ...,
        footprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "host_uid", b"host_uid", "read_offset", b"read_offset"]) -> None: ...

global___DynAllUpdOffsetReq = DynAllUpdOffsetReq

@typing_extensions.final
class DynDetailReply(google.protobuf.message.Message):
    """动态详情页-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DynamicItem:
        """动态详情"""
    def __init__(
        self,
        *,
        item: global___DynamicItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___DynDetailReply = DynDetailReply

@typing_extensions.final
class DynDetailsReq(google.protobuf.message.Message):
    """批量动态id获取动态详情-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_IDS_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    dynamic_ids: builtins.str
    """动态id"""
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    @property
    def player_args(self) -> global___PlayerArgs:
        """秒开参数"""
    def __init__(
        self,
        *,
        dynamic_ids: builtins.str = ...,
        playurl_param: global___PlayurlParam | None = ...,
        local_time: builtins.int = ...,
        player_args: global___PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args", "playurl_param", b"playurl_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_ids", b"dynamic_ids", "local_time", b"local_time", "player_args", b"player_args", "playurl_param", b"playurl_param"]) -> None: ...

global___DynDetailsReq = DynDetailsReq

@typing_extensions.final
class DynFakeCardReply(google.protobuf.message.Message):
    """动态发布生成临时卡-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DynamicItem:
        """动态卡片"""
    def __init__(
        self,
        *,
        item: global___DynamicItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___DynFakeCardReply = DynFakeCardReply

@typing_extensions.final
class DynFakeCardReq(google.protobuf.message.Message):
    """动态发布生成临时卡-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """卡片内容json string"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___DynFakeCardReq = DynFakeCardReq

@typing_extensions.final
class DynMixUpListViewMoreReply(google.protobuf.message.Message):
    """查看更多-列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    SEARCH_DEFAULT_TEXT_FIELD_NUMBER: builtins.int
    SORT_TYPES_FIELD_NUMBER: builtins.int
    SHOW_MORE_SORT_TYPES_FIELD_NUMBER: builtins.int
    DEFAULT_SORT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MixUpListItem]:
        """"""
    search_default_text: builtins.str
    """"""
    @property
    def sort_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortType]:
        """排序类型列表"""
    show_more_sort_types: builtins.bool
    """是否展示更多的排序策略"""
    default_sort_type: builtins.int
    """默认排序策略"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___MixUpListItem] | None = ...,
        search_default_text: builtins.str = ...,
        sort_types: collections.abc.Iterable[global___SortType] | None = ...,
        show_more_sort_types: builtins.bool = ...,
        default_sort_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_sort_type", b"default_sort_type", "items", b"items", "search_default_text", b"search_default_text", "show_more_sort_types", b"show_more_sort_types", "sort_types", b"sort_types"]) -> None: ...

global___DynMixUpListViewMoreReply = DynMixUpListViewMoreReply

@typing_extensions.final
class DynMixUpListViewMoreReq(google.protobuf.message.Message):
    """查看更多-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORT_TYPE_FIELD_NUMBER: builtins.int
    sort_type: builtins.int
    """排序策略
    1:推荐排序 2:最常访问 3:最近关注，其他值为默认排序
    """
    def __init__(
        self,
        *,
        sort_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort_type", b"sort_type"]) -> None: ...

global___DynMixUpListViewMoreReq = DynMixUpListViewMoreReq

@typing_extensions.final
class DynRcmdUpExchangeReply(google.protobuf.message.Message):
    """关注推荐up主换一换-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNFOLLOW_FIELD_NUMBER: builtins.int
    @property
    def unfollow(self) -> global___Unfollow:
        """无关注推荐"""
    def __init__(
        self,
        *,
        unfollow: global___Unfollow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["unfollow", b"unfollow"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["unfollow", b"unfollow"]) -> None: ...

global___DynRcmdUpExchangeReply = DynRcmdUpExchangeReply

@typing_extensions.final
class DynRcmdUpExchangeReq(google.protobuf.message.Message):
    """关注推荐up主换一换-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    DISLIKETS_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """登录用户id"""
    dislikeTs: builtins.int
    """上一次不感兴趣的ts，单位：秒；该字段透传给搜索"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        dislikeTs: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislikeTs", b"dislikeTs", "from", b"from", "uid", b"uid"]) -> None: ...

global___DynRcmdUpExchangeReq = DynRcmdUpExchangeReq

@typing_extensions.final
class DynThumbReq(google.protobuf.message.Message):
    """动态点赞-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    DYN_ID_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户uid"""
    dyn_id: builtins.str
    """动态id"""
    dyn_type: builtins.int
    """动态类型(透传extend中的dyn_type)"""
    rid: builtins.str
    """业务方资源id"""
    type: global___ThumbType.ValueType
    """点赞类型"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        dyn_id: builtins.str = ...,
        dyn_type: builtins.int = ...,
        rid: builtins.str = ...,
        type: global___ThumbType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_id", b"dyn_id", "dyn_type", b"dyn_type", "rid", b"rid", "type", b"type", "uid", b"uid"]) -> None: ...

global___DynThumbReq = DynThumbReq

@typing_extensions.final
class DynVideoPersonalReply(google.protobuf.message.Message):
    """最近访问-个人feed流列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    offset: builtins.str
    """偏移量"""
    has_more: builtins.bool
    """是否还有更多数据"""
    read_offset: builtins.str
    """已读进度"""
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        read_offset: builtins.str = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset", "read_offset", b"read_offset", "relation", b"relation"]) -> None: ...

global___DynVideoPersonalReply = DynVideoPersonalReply

@typing_extensions.final
class DynVideoPersonalReq(google.protobuf.message.Message):
    """最近访问-个人feed流列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    IS_PRELOAD_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的 UID"""
    offset: builtins.str
    """偏移量 第一页可传空"""
    page: builtins.int
    """标明下拉几次"""
    is_preload: builtins.int
    """是否是预加载"""
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    @property
    def player_args(self) -> global___PlayerArgs:
        """秒开参数"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        offset: builtins.str = ...,
        page: builtins.int = ...,
        is_preload: builtins.int = ...,
        playurl_param: global___PlayurlParam | None = ...,
        local_time: builtins.int = ...,
        footprint: builtins.str = ...,
        player_args: global___PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args", "playurl_param", b"playurl_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "from", b"from", "host_uid", b"host_uid", "is_preload", b"is_preload", "local_time", b"local_time", "offset", b"offset", "page", b"page", "player_args", b"player_args", "playurl_param", b"playurl_param"]) -> None: ...

global___DynVideoPersonalReq = DynVideoPersonalReq

@typing_extensions.final
class DynVideoReply(google.protobuf.message.Message):
    """动态视频页-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_LIST_FIELD_NUMBER: builtins.int
    VIDEO_UP_LIST_FIELD_NUMBER: builtins.int
    VIDEO_FOLLOW_LIST_FIELD_NUMBER: builtins.int
    @property
    def dynamic_list(self) -> global___CardVideoDynList:
        """卡片列表"""
    @property
    def video_up_list(self) -> global___CardVideoUpList:
        """动态卡片"""
    @property
    def video_follow_list(self) -> global___CardVideoFollowList:
        """视频页-我的追番"""
    def __init__(
        self,
        *,
        dynamic_list: global___CardVideoDynList | None = ...,
        video_up_list: global___CardVideoUpList | None = ...,
        video_follow_list: global___CardVideoFollowList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list", "video_follow_list", b"video_follow_list", "video_up_list", b"video_up_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list", "video_follow_list", b"video_follow_list", "video_up_list", b"video_up_list"]) -> None: ...

global___DynVideoReply = DynVideoReply

@typing_extensions.final
class DynVideoReq(google.protobuf.message.Message):
    """动态视频页-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    REFRESH_TYPE_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    ASSIST_BASELINE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    update_baseline: builtins.str
    """透传 update_baseline"""
    offset: builtins.str
    """透传 history_offset"""
    page: builtins.int
    """向下翻页数"""
    refresh_type: global___Refresh.ValueType
    """刷新方式
    1:向上刷新 2:向下翻页
    """
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    assist_baseline: builtins.str
    """综合页当前更新的最大值"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    @property
    def player_args(self) -> global___PlayerArgs:
        """秒开参数"""
    def __init__(
        self,
        *,
        update_baseline: builtins.str = ...,
        offset: builtins.str = ...,
        page: builtins.int = ...,
        refresh_type: global___Refresh.ValueType = ...,
        playurl_param: global___PlayurlParam | None = ...,
        assist_baseline: builtins.str = ...,
        local_time: builtins.int = ...,
        player_args: global___PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args", "playurl_param", b"playurl_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assist_baseline", b"assist_baseline", "from", b"from", "local_time", b"local_time", "offset", b"offset", "page", b"page", "player_args", b"player_args", "playurl_param", b"playurl_param", "refresh_type", b"refresh_type", "update_baseline", b"update_baseline"]) -> None: ...

global___DynVideoReq = DynVideoReq

@typing_extensions.final
class DynVideoUpdOffsetReq(google.protobuf.message.Message):
    """最近访问-标记已读-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的UID"""
    read_offset: builtins.str
    """用户已读进度"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        read_offset: builtins.str = ...,
        footprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "host_uid", b"host_uid", "read_offset", b"read_offset"]) -> None: ...

global___DynVideoUpdOffsetReq = DynVideoUpdOffsetReq

@typing_extensions.final
class DynVoteReply(google.protobuf.message.Message):
    """投票操作-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___AdditionVote2:
        """投票详情"""
    toast: builtins.str
    """投票操作返回状态"""
    def __init__(
        self,
        *,
        item: global___AdditionVote2 | None = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "toast", b"toast"]) -> None: ...

global___DynVoteReply = DynVoteReply

@typing_extensions.final
class DynVoteReq(google.protobuf.message.Message):
    """投票操作-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOTE_ID_FIELD_NUMBER: builtins.int
    VOTES_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    vote_id: builtins.int
    """投票ID"""
    @property
    def votes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """选项索引数组"""
    status: global___VoteStatus.ValueType
    """状态"""
    dynamic_id: builtins.str
    """动态ID"""
    share: builtins.bool
    """是否分享"""
    def __init__(
        self,
        *,
        vote_id: builtins.int = ...,
        votes: collections.abc.Iterable[builtins.int] | None = ...,
        status: global___VoteStatus.ValueType = ...,
        dynamic_id: builtins.str = ...,
        share: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_id", b"dynamic_id", "share", b"share", "status", b"status", "vote_id", b"vote_id", "votes", b"votes"]) -> None: ...

global___DynVoteReq = DynVoteReq

@typing_extensions.final
class DynamicItem(google.protobuf.message.Message):
    """动态卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CARD_TYPE_FIELD_NUMBER: builtins.int
    ITEM_TYPE_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    EXTEND_FIELD_NUMBER: builtins.int
    HAS_FOLD_FIELD_NUMBER: builtins.int
    card_type: global___DynamicType.ValueType
    """动态卡片类型"""
    item_type: global___DynamicType.ValueType
    """转发类型下，源卡片类型"""
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Module]:
        """模块内容"""
    @property
    def extend(self) -> global___Extend:
        """操作相关字段"""
    has_fold: builtins.int
    """该卡片下面是否含有折叠卡"""
    def __init__(
        self,
        *,
        card_type: global___DynamicType.ValueType = ...,
        item_type: global___DynamicType.ValueType = ...,
        modules: collections.abc.Iterable[global___Module] | None = ...,
        extend: global___Extend | None = ...,
        has_fold: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extend", b"extend"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type", b"card_type", "extend", b"extend", "has_fold", b"has_fold", "item_type", b"item_type", "modules", b"modules"]) -> None: ...

global___DynamicItem = DynamicItem

@typing_extensions.final
class DynamicList(google.protobuf.message.Message):
    """动态卡片列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    UPDATE_NUM_FIELD_NUMBER: builtins.int
    HISTORY_OFFSET_FIELD_NUMBER: builtins.int
    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    update_num: builtins.int
    """更新的动态数"""
    history_offset: builtins.str
    """历史偏移"""
    update_baseline: builtins.str
    """更新基础信息"""
    has_more: builtins.bool
    """是否还有更多数据"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        update_num: builtins.int = ...,
        history_offset: builtins.str = ...,
        update_baseline: builtins.str = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "history_offset", b"history_offset", "list", b"list", "update_baseline", b"update_baseline", "update_num", b"update_num"]) -> None: ...

global___DynamicList = DynamicList

@typing_extensions.final
class ExtInfoCommon(google.protobuf.message.Message):
    """动态-拓展小卡模块-通用小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    POI_TYPE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SUB_MODULE_FIELD_NUMBER: builtins.int
    ACTION_TEXT_FIELD_NUMBER: builtins.int
    ACTION_URL_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    IS_SHOW_LIGHT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    poi_type: builtins.int
    """poiType"""
    type: global___DynExtendType.ValueType
    """类型"""
    sub_module: builtins.str
    """客户端埋点用"""
    action_text: builtins.str
    """行动点文案"""
    action_url: builtins.str
    """行动点链接"""
    rid: builtins.int
    """资源rid"""
    is_show_light: builtins.bool
    """轻浏览是否展示"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
        poi_type: builtins.int = ...,
        type: global___DynExtendType.ValueType = ...,
        sub_module: builtins.str = ...,
        action_text: builtins.str = ...,
        action_url: builtins.str = ...,
        rid: builtins.int = ...,
        is_show_light: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_text", b"action_text", "action_url", b"action_url", "icon", b"icon", "is_show_light", b"is_show_light", "poi_type", b"poi_type", "rid", b"rid", "sub_module", b"sub_module", "title", b"title", "type", b"type", "uri", b"uri"]) -> None: ...

global___ExtInfoCommon = ExtInfoCommon

@typing_extensions.final
class ExtInfoGame(google.protobuf.message.Message):
    """动态-拓展小卡模块-游戏小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___ExtInfoGame = ExtInfoGame

@typing_extensions.final
class ExtInfoHot(google.protobuf.message.Message):
    """动态-拓展小卡模块-热门小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___ExtInfoHot = ExtInfoHot

@typing_extensions.final
class ExtInfoLBS(google.protobuf.message.Message):
    """动态-拓展小卡模块-lbs小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    POI_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    poi_type: builtins.int
    """poiType"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
        poi_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "poi_type", b"poi_type", "title", b"title", "uri", b"uri"]) -> None: ...

global___ExtInfoLBS = ExtInfoLBS

@typing_extensions.final
class ExtInfoOGV(google.protobuf.message.Message):
    """动态-拓展小卡模块-ogv小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_OGV_FIELD_NUMBER: builtins.int
    @property
    def info_ogv(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InfoOGV]:
        """ogv小卡"""
    def __init__(
        self,
        *,
        info_ogv: collections.abc.Iterable[global___InfoOGV] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["info_ogv", b"info_ogv"]) -> None: ...

global___ExtInfoOGV = ExtInfoOGV

@typing_extensions.final
class ExtInfoTopic(google.protobuf.message.Message):
    """动态-拓展小卡模块-话题小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题-话题名"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___ExtInfoTopic = ExtInfoTopic

@typing_extensions.final
class Extend(google.protobuf.message.Message):
    """扩展字段，用于动态部分操作使用"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYN_ID_STR_FIELD_NUMBER: builtins.int
    BUSINESS_ID_FIELD_NUMBER: builtins.int
    ORIG_DYN_ID_STR_FIELD_NUMBER: builtins.int
    ORIG_NAME_FIELD_NUMBER: builtins.int
    ORIG_IMG_URL_FIELD_NUMBER: builtins.int
    ORIG_DESC_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    ORIG_DYN_TYPE_FIELD_NUMBER: builtins.int
    SHARE_TYPE_FIELD_NUMBER: builtins.int
    SHARE_SCENE_FIELD_NUMBER: builtins.int
    IS_FAST_SHARE_FIELD_NUMBER: builtins.int
    R_TYPE_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    CARD_URL_FIELD_NUMBER: builtins.int
    SOURCE_CONTENT_FIELD_NUMBER: builtins.int
    ORIG_FACE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    dyn_id_str: builtins.str
    """动态id"""
    business_id: builtins.str
    """业务方id"""
    orig_dyn_id_str: builtins.str
    """源动态id"""
    orig_name: builtins.str
    """转发卡：用户名"""
    orig_img_url: builtins.str
    """转发卡：图片url"""
    @property
    def orig_desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """转发卡：文字内容"""
    @property
    def desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """填充文字内容"""
    orig_dyn_type: global___DynamicType.ValueType
    """被转发的源动态类型"""
    share_type: builtins.str
    """分享到站外展示类型"""
    share_scene: builtins.str
    """分享的场景"""
    is_fast_share: builtins.bool
    """是否快速转发"""
    r_type: builtins.int
    """r_type 分享和转发"""
    dyn_type: builtins.int
    """数据源的动态类型"""
    uid: builtins.int
    """用户id"""
    card_url: builtins.str
    """卡片跳转"""
    @property
    def source_content(self) -> google.protobuf.any_pb2.Any:
        """透传字段"""
    orig_face: builtins.str
    """转发卡：用户头像"""
    @property
    def reply(self) -> global___ExtendReply:
        """评论跳转"""
    def __init__(
        self,
        *,
        dyn_id_str: builtins.str = ...,
        business_id: builtins.str = ...,
        orig_dyn_id_str: builtins.str = ...,
        orig_name: builtins.str = ...,
        orig_img_url: builtins.str = ...,
        orig_desc: collections.abc.Iterable[global___Description] | None = ...,
        desc: collections.abc.Iterable[global___Description] | None = ...,
        orig_dyn_type: global___DynamicType.ValueType = ...,
        share_type: builtins.str = ...,
        share_scene: builtins.str = ...,
        is_fast_share: builtins.bool = ...,
        r_type: builtins.int = ...,
        dyn_type: builtins.int = ...,
        uid: builtins.int = ...,
        card_url: builtins.str = ...,
        source_content: google.protobuf.any_pb2.Any | None = ...,
        orig_face: builtins.str = ...,
        reply: global___ExtendReply | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reply", b"reply", "source_content", b"source_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business_id", b"business_id", "card_url", b"card_url", "desc", b"desc", "dyn_id_str", b"dyn_id_str", "dyn_type", b"dyn_type", "is_fast_share", b"is_fast_share", "orig_desc", b"orig_desc", "orig_dyn_id_str", b"orig_dyn_id_str", "orig_dyn_type", b"orig_dyn_type", "orig_face", b"orig_face", "orig_img_url", b"orig_img_url", "orig_name", b"orig_name", "r_type", b"r_type", "reply", b"reply", "share_scene", b"share_scene", "share_type", b"share_type", "source_content", b"source_content", "uid", b"uid"]) -> None: ...

global___Extend = Extend

@typing_extensions.final
class ExtendReply(google.protobuf.message.Message):
    """评论扩展"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    uri: builtins.str
    """基础跳转地址"""
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtendReplyParam]:
        """参数部分"""
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        params: collections.abc.Iterable[global___ExtendReplyParam] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params", "uri", b"uri"]) -> None: ...

global___ExtendReply = ExtendReply

@typing_extensions.final
class ExtendReplyParam(google.protobuf.message.Message):
    """评论扩展参数部分"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """参数名"""
    value: builtins.str
    """参数值"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___ExtendReplyParam = ExtendReplyParam

@typing_extensions.final
class FollowListItem(google.protobuf.message.Message):
    """视频页-我的追番-番剧信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    NEW_EP_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """season_id"""
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    url: builtins.str
    """跳转链接"""
    @property
    def new_ep(self) -> global___NewEP:
        """new_ep"""
    sub_title: builtins.str
    """子标题"""
    pos: builtins.int
    """卡片位次"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        url: builtins.str = ...,
        new_ep: global___NewEP | None = ...,
        sub_title: builtins.str = ...,
        pos: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["new_ep", b"new_ep"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "new_ep", b"new_ep", "pos", b"pos", "season_id", b"season_id", "sub_title", b"sub_title", "title", b"title", "url", b"url"]) -> None: ...

global___FollowListItem = FollowListItem

@typing_extensions.final
class GoodsItem(google.protobuf.message.Message):
    """动态-附加卡-商品卡-商品"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    SCHEMA_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    JUMP_DESC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BRIEF_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    OPEN_WHITE_LIST_FIELD_NUMBER: builtins.int
    USER_WEB_V2_FIELD_NUMBER: builtins.int
    AD_MARK_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """图片"""
    schema_package_name: builtins.str
    """schemaPackageName(Android用)"""
    source_type: builtins.int
    """商品类型
    1:淘宝 2:会员购
    """
    jump_url: builtins.str
    """跳转链接"""
    jump_desc: builtins.str
    """跳转文案"""
    title: builtins.str
    """标题"""
    brief: builtins.str
    """摘要"""
    price: builtins.str
    """价格"""
    item_id: builtins.int
    """item_id"""
    schema_url: builtins.str
    """schema_url"""
    @property
    def open_white_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """open_white_list"""
    user_web_v2: builtins.bool
    """use_web_v2"""
    ad_mark: builtins.str
    """ad mark"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        schema_package_name: builtins.str = ...,
        source_type: builtins.int = ...,
        jump_url: builtins.str = ...,
        jump_desc: builtins.str = ...,
        title: builtins.str = ...,
        brief: builtins.str = ...,
        price: builtins.str = ...,
        item_id: builtins.int = ...,
        schema_url: builtins.str = ...,
        open_white_list: collections.abc.Iterable[builtins.str] | None = ...,
        user_web_v2: builtins.bool = ...,
        ad_mark: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_mark", b"ad_mark", "brief", b"brief", "cover", b"cover", "item_id", b"item_id", "jump_desc", b"jump_desc", "jump_url", b"jump_url", "open_white_list", b"open_white_list", "price", b"price", "schema_package_name", b"schema_package_name", "schema_url", b"schema_url", "source_type", b"source_type", "title", b"title", "user_web_v2", b"user_web_v2"]) -> None: ...

global___GoodsItem = GoodsItem

@typing_extensions.final
class HighlightText(google.protobuf.message.Message):
    """高亮文本"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_STYLE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """展示文本"""
    text_style: global___HighlightTextStyle.ValueType
    """高亮类型"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_style: global___HighlightTextStyle.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "text_style", b"text_style"]) -> None: ...

global___HighlightText = HighlightText

@typing_extensions.final
class InfoOGV(google.protobuf.message.Message):
    """动态-拓展小卡模块-ogv小卡-(one of 片单、榜单、分区)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SUB_MODULE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    sub_module: builtins.str
    """客户端埋点用"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
        sub_module: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "sub_module", b"sub_module", "title", b"title", "uri", b"uri"]) -> None: ...

global___InfoOGV = InfoOGV

@typing_extensions.final
class InteractionItem(google.protobuf.message.Message):
    """外露交互模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    COMMENT_MID_FIELD_NUMBER: builtins.int
    icon_type: global___LocalIconType.ValueType
    """外露模块类型"""
    @property
    def desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """外露模块文案"""
    uri: builtins.str
    """外露模块uri相关 根据type不同用法不同"""
    dynamic_id: builtins.str
    """动态id"""
    comment_mid: builtins.int
    """评论mid"""
    def __init__(
        self,
        *,
        icon_type: global___LocalIconType.ValueType = ...,
        desc: collections.abc.Iterable[global___Description] | None = ...,
        uri: builtins.str = ...,
        dynamic_id: builtins.str = ...,
        comment_mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment_mid", b"comment_mid", "desc", b"desc", "dynamic_id", b"dynamic_id", "icon_type", b"icon_type", "uri", b"uri"]) -> None: ...

global___InteractionItem = InteractionItem

@typing_extensions.final
class LikeAnimation(google.protobuf.message.Message):
    """点赞动画"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_FIELD_NUMBER: builtins.int
    PROC_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    LIKE_ICON_ID_FIELD_NUMBER: builtins.int
    begin: builtins.str
    """开始动画"""
    proc: builtins.str
    """过程动画"""
    end: builtins.str
    """结束动画"""
    like_icon_id: builtins.int
    """id"""
    def __init__(
        self,
        *,
        begin: builtins.str = ...,
        proc: builtins.str = ...,
        end: builtins.str = ...,
        like_icon_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin", b"begin", "end", b"end", "like_icon_id", b"like_icon_id", "proc", b"proc"]) -> None: ...

global___LikeAnimation = LikeAnimation

@typing_extensions.final
class LikeInfo(google.protobuf.message.Message):
    """点赞拓展信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANIMATION_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    @property
    def animation(self) -> global___LikeAnimation:
        """点赞动画"""
    is_like: builtins.bool
    """是否点赞"""
    def __init__(
        self,
        *,
        animation: global___LikeAnimation | None = ...,
        is_like: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["animation", b"animation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animation", b"animation", "is_like", b"is_like"]) -> None: ...

global___LikeInfo = LikeInfo

@typing_extensions.final
class LikeUser(google.protobuf.message.Message):
    """点赞用户"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    UNAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""
    uname: builtins.str
    """用户昵称"""
    uri: builtins.str
    """点击跳转链接"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        uname: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uid", b"uid", "uname", b"uname", "uri", b"uri"]) -> None: ...

global___LikeUser = LikeUser

@typing_extensions.final
class LiveInfo(google.protobuf.message.Message):
    """直播信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_LIVING_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    is_living: builtins.int
    """是否在直播
    0:未直播 1:正在直播 (废弃)
    """
    uri: builtins.str
    """跳转链接"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    def __init__(
        self,
        *,
        is_living: builtins.int = ...,
        uri: builtins.str = ...,
        live_state: global___LiveState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_living", b"is_living", "live_state", b"live_state", "uri", b"uri"]) -> None: ...

global___LiveInfo = LiveInfo

@typing_extensions.final
class MatchTeam(google.protobuf.message.Message):
    """动态-附加卡-电竞卡-战队"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    NIGHT_COLOR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """战队ID"""
    name: builtins.str
    """战队名"""
    cover: builtins.str
    """战队图标"""
    color: builtins.str
    """日间色值"""
    night_color: builtins.str
    """夜间色值"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        cover: builtins.str = ...,
        color: builtins.str = ...,
        night_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "cover", b"cover", "id", b"id", "name", b"name", "night_color", b"night_color"]) -> None: ...

global___MatchTeam = MatchTeam

@typing_extensions.final
class MdlDynApplet(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-小程序/小游戏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """小程序id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """主标题"""
    sub_title: builtins.str
    """副标题"""
    cover: builtins.str
    """封面图"""
    icon: builtins.str
    """小程序icon"""
    label: builtins.str
    """小程序标题"""
    button_title: builtins.str
    """按钮文案"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        sub_title: builtins.str = ...,
        cover: builtins.str = ...,
        icon: builtins.str = ...,
        label: builtins.str = ...,
        button_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_title", b"button_title", "cover", b"cover", "icon", b"icon", "id", b"id", "label", b"label", "sub_title", b"sub_title", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynApplet = MdlDynApplet

@typing_extensions.final
class MdlDynArchive(google.protobuf.message.Message):
    """动态-详情模块-稿件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    STYPE_FIELD_NUMBER: builtins.int
    ISPGC_FIELD_NUMBER: builtins.int
    INLINEURL_FIELD_NUMBER: builtins.int
    EPISODEID_FIELD_NUMBER: builtins.int
    SUBTYPE_FIELD_NUMBER: builtins.int
    PGCSEASONID_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    BADGE_CATEGORY_FIELD_NUMBER: builtins.int
    IS_FEATURE_FIELD_NUMBER: builtins.int
    RESERVE_TYPE_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """秒开地址"""
    cover_left_text_1: builtins.str
    """视频封面展示项 1"""
    cover_left_text_2: builtins.str
    """视频封面展示项 2"""
    cover_left_text_3: builtins.str
    """封面视频展示项 3"""
    avid: builtins.int
    """avid"""
    cid: builtins.int
    """cid"""
    media_type: global___MediaType.ValueType
    """视频源类型"""
    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标，多个角标之前有间距"""
    can_play: builtins.bool
    """是否能够自动播放"""
    stype: global___VideoType.ValueType
    """stype"""
    isPGC: builtins.bool
    """是否PGC"""
    inlineURL: builtins.str
    """inline播放地址"""
    EpisodeId: builtins.int
    """PGC的epid"""
    SubType: builtins.int
    """子类型"""
    PgcSeasonId: builtins.int
    """PGC的ssid"""
    play_icon: builtins.str
    """播放按钮"""
    duration: builtins.int
    """时长"""
    jump_url: builtins.str
    """跳转地址"""
    is_preview: builtins.bool
    """番剧是否为预览视频"""
    @property
    def badge_category(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """新角标，多个角标之前没有间距"""
    is_feature: builtins.bool
    """当前是否是pgc正片"""
    reserve_type: global___ReserveType.ValueType
    """是否是预约召回"""
    bvid: builtins.str
    """bvid"""
    view: builtins.int
    """播放数"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        avid: builtins.int = ...,
        cid: builtins.int = ...,
        media_type: global___MediaType.ValueType = ...,
        dimension: global___Dimension | None = ...,
        badge: collections.abc.Iterable[global___VideoBadge] | None = ...,
        can_play: builtins.bool = ...,
        stype: global___VideoType.ValueType = ...,
        isPGC: builtins.bool = ...,
        inlineURL: builtins.str = ...,
        EpisodeId: builtins.int = ...,
        SubType: builtins.int = ...,
        PgcSeasonId: builtins.int = ...,
        play_icon: builtins.str = ...,
        duration: builtins.int = ...,
        jump_url: builtins.str = ...,
        is_preview: builtins.bool = ...,
        badge_category: collections.abc.Iterable[global___VideoBadge] | None = ...,
        is_feature: builtins.bool = ...,
        reserve_type: global___ReserveType.ValueType = ...,
        bvid: builtins.str = ...,
        view: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["EpisodeId", b"EpisodeId", "PgcSeasonId", b"PgcSeasonId", "SubType", b"SubType", "avid", b"avid", "badge", b"badge", "badge_category", b"badge_category", "bvid", b"bvid", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "dimension", b"dimension", "duration", b"duration", "inlineURL", b"inlineURL", "isPGC", b"isPGC", "is_feature", b"is_feature", "is_preview", b"is_preview", "jump_url", b"jump_url", "media_type", b"media_type", "play_icon", b"play_icon", "reserve_type", b"reserve_type", "stype", b"stype", "title", b"title", "uri", b"uri", "view", b"view"]) -> None: ...

global___MdlDynArchive = MdlDynArchive

@typing_extensions.final
class MdlDynArticle(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-专栏模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVERS_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    TEMPLATEID_FIELD_NUMBER: builtins.int
    id: builtins.int
    """专栏id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """标题"""
    desc: builtins.str
    """文案部分"""
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """配图"""
    label: builtins.str
    """阅读量标签"""
    templateID: builtins.int
    """模板类型"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        covers: collections.abc.Iterable[builtins.str] | None = ...,
        label: builtins.str = ...,
        templateID: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["covers", b"covers", "desc", b"desc", "id", b"id", "label", b"label", "templateID", b"templateID", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynArticle = MdlDynArticle

@typing_extensions.final
class MdlDynCommon(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-通用"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BIZTYPE_FIELD_NUMBER: builtins.int
    SKETCHID_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """物料id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """标题"""
    desc: builtins.str
    """描述 漫画卡标题下第一行"""
    cover: builtins.str
    """封面"""
    label: builtins.str
    """标签1 漫画卡标题下第二行"""
    bizType: builtins.int
    """所属业务类型"""
    sketchID: builtins.int
    """镜像数据ID"""
    style: global___MdlDynCommonType.ValueType
    """卡片样式"""
    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        cover: builtins.str = ...,
        label: builtins.str = ...,
        bizType: builtins.int = ...,
        sketchID: builtins.int = ...,
        style: global___MdlDynCommonType.ValueType = ...,
        badge: collections.abc.Iterable[global___VideoBadge] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "bizType", b"bizType", "cover", b"cover", "desc", b"desc", "label", b"label", "oid", b"oid", "sketchID", b"sketchID", "style", b"style", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynCommon = MdlDynCommon

@typing_extensions.final
class MdlDynCourBatch(google.protobuf.message.Message):
    """动态-详情模块-付费课程批次"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    TEXT_2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """跳转地址"""
    text_1: builtins.str
    """展示项 1(本集标题)"""
    text_2: builtins.str
    """展示项 2(更新了多少个视频)"""
    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
    play_icon: builtins.str
    """播放按钮"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        text_1: builtins.str = ...,
        text_2: builtins.str = ...,
        badge: global___VideoBadge | None = ...,
        play_icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "cover", b"cover", "play_icon", b"play_icon", "text_1", b"text_1", "text_2", b"text_2", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynCourBatch = MdlDynCourBatch

@typing_extensions.final
class MdlDynCourSeason(google.protobuf.message.Message):
    """动态-详情模块-付费课程系列"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """跳转地址"""
    text_1: builtins.str
    """展示项 1(更新信息)"""
    desc: builtins.str
    """描述信息"""
    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
    play_icon: builtins.str
    """播放按钮"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        text_1: builtins.str = ...,
        desc: builtins.str = ...,
        badge: global___VideoBadge | None = ...,
        play_icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "cover", b"cover", "desc", b"desc", "play_icon", b"play_icon", "text_1", b"text_1", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynCourSeason = MdlDynCourSeason

@typing_extensions.final
class MdlDynDraw(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-图文模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MdlDynDrawItem]:
        """图片"""
    uri: builtins.str
    """跳转地址"""
    id: builtins.int
    """图文ID"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___MdlDynDrawItem] | None = ...,
        uri: builtins.str = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "items", b"items", "uri", b"uri"]) -> None: ...

global___MdlDynDraw = MdlDynDraw

@typing_extensions.final
class MdlDynDrawItem(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-图文"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SRC_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    src: builtins.str
    """图片链接"""
    width: builtins.int
    """图片宽度"""
    height: builtins.int
    """图片高度"""
    size: builtins.float
    """图片大小"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MdlDynDrawTag]:
        """图片标签"""
    def __init__(
        self,
        *,
        src: builtins.str = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        size: builtins.float = ...,
        tags: collections.abc.Iterable[global___MdlDynDrawTag] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "size", b"size", "src", b"src", "tags", b"tags", "width", b"width"]) -> None: ...

global___MdlDynDrawItem = MdlDynDrawItem

@typing_extensions.final
class MdlDynDrawTag(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-图文-标签"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    type: global___MdlDynDrawTagType.ValueType
    """标签类型"""
    @property
    def item(self) -> global___MdlDynDrawTagItem:
        """标签详情"""
    def __init__(
        self,
        *,
        type: global___MdlDynDrawTagType.ValueType = ...,
        item: global___MdlDynDrawTagItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "type", b"type"]) -> None: ...

global___MdlDynDrawTag = MdlDynDrawTag

@typing_extensions.final
class MdlDynDrawTagItem(google.protobuf.message.Message):
    """动态列表部分-详情模块-图文-标签详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    ORIENTATION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    POI_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """跳转链接"""
    text: builtins.str
    """标签内容"""
    x: builtins.int
    """坐标-x"""
    y: builtins.int
    """坐标-y"""
    orientation: builtins.int
    """方向"""
    source: builtins.int
    """来源
    0:未知 1:淘宝 2:自营
    """
    item_id: builtins.int
    """商品id"""
    mid: builtins.int
    """用户mid"""
    tid: builtins.int
    """话题id"""
    poi: builtins.str
    """lbs信息"""
    schema_url: builtins.str
    """商品标签链接"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        text: builtins.str = ...,
        x: builtins.int = ...,
        y: builtins.int = ...,
        orientation: builtins.int = ...,
        source: builtins.int = ...,
        item_id: builtins.int = ...,
        mid: builtins.int = ...,
        tid: builtins.int = ...,
        poi: builtins.str = ...,
        schema_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_id", b"item_id", "mid", b"mid", "orientation", b"orientation", "poi", b"poi", "schema_url", b"schema_url", "source", b"source", "text", b"text", "tid", b"tid", "url", b"url", "x", b"x", "y", b"y"]) -> None: ...

global___MdlDynDrawTagItem = MdlDynDrawTagItem

@typing_extensions.final
class MdlDynForward(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-转发模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    RTYPE_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DynamicItem:
        """动态转发核心模块 套娃"""
    rtype: builtins.int
    """透传类型
    0:分享 1:转发
    """
    def __init__(
        self,
        *,
        item: global___DynamicItem | None = ...,
        rtype: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "rtype", b"rtype"]) -> None: ...

global___MdlDynForward = MdlDynForward

@typing_extensions.final
class MdlDynLive(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-直播"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_LABEL_FIELD_NUMBER: builtins.int
    COVER_LABEL2_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RESERVE_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """房间号"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """直播间标题"""
    cover: builtins.str
    """直播间封面"""
    cover_label: builtins.str
    """标题1 例: 陪伴学习"""
    cover_label2: builtins.str
    """标题2 例: 54.6万人气"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    @property
    def badge(self) -> global___VideoBadge:
        """直播角标"""
    reserve_type: global___ReserveType.ValueType
    """是否是预约召回"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_label: builtins.str = ...,
        cover_label2: builtins.str = ...,
        live_state: global___LiveState.ValueType = ...,
        badge: global___VideoBadge | None = ...,
        reserve_type: global___ReserveType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "cover", b"cover", "cover_label", b"cover_label", "cover_label2", b"cover_label2", "id", b"id", "live_state", b"live_state", "reserve_type", b"reserve_type", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynLive = MdlDynLive

@typing_extensions.final
class MdlDynLiveRcmd(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-直播推荐"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    RESERVE_TYPE_FIELD_NUMBER: builtins.int
    content: builtins.str
    """直播数据"""
    reserve_type: global___ReserveType.ValueType
    """是否是预约召回"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        reserve_type: global___ReserveType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "reserve_type", b"reserve_type"]) -> None: ...

global___MdlDynLiveRcmd = MdlDynLiveRcmd

@typing_extensions.final
class MdlDynMedialist(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-播单"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_TYPE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """播单id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """主标题"""
    sub_title: builtins.str
    """副标题"""
    cover: builtins.str
    """封面图"""
    cover_type: builtins.int
    """封面类型"""
    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        sub_title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_type: builtins.int = ...,
        badge: global___VideoBadge | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "cover", b"cover", "cover_type", b"cover_type", "id", b"id", "sub_title", b"sub_title", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynMedialist = MdlDynMedialist

@typing_extensions.final
class MdlDynMusic(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-音频模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    UP_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LABEL1_FIELD_NUMBER: builtins.int
    UPPER_FIELD_NUMBER: builtins.int
    id: builtins.int
    """音频id"""
    uri: builtins.str
    """跳转地址"""
    up_id: builtins.int
    """upId"""
    title: builtins.str
    """歌名"""
    cover: builtins.str
    """专辑封面"""
    label1: builtins.str
    """展示项1"""
    upper: builtins.str
    """upper"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        up_id: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        label1: builtins.str = ...,
        upper: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "id", b"id", "label1", b"label1", "title", b"title", "up_id", b"up_id", "upper", b"upper", "uri", b"uri"]) -> None: ...

global___MdlDynMusic = MdlDynMusic

@typing_extensions.final
class MdlDynPGC(google.protobuf.message.Message):
    """动态-详情模块-pgc"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    SEASON_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    BADGE_CATEGORY_FIELD_NUMBER: builtins.int
    IS_FEATURE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """秒开地址"""
    cover_left_text_1: builtins.str
    """视频封面展示项 1"""
    cover_left_text_2: builtins.str
    """视频封面展示项 2"""
    cover_left_text_3: builtins.str
    """封面视频展示项 3"""
    cid: builtins.int
    """cid"""
    season_id: builtins.int
    """season_id"""
    epid: builtins.int
    """epid"""
    aid: builtins.int
    """aid"""
    media_type: global___MediaType.ValueType
    """视频源类型"""
    sub_type: global___VideoSubType.ValueType
    """番剧类型"""
    is_preview: builtins.bool
    """番剧是否为预览视频"""
    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标，多个角标之前有间距"""
    can_play: builtins.bool
    """是否能够自动播放"""
    @property
    def season(self) -> global___PGCSeason:
        """season"""
    play_icon: builtins.str
    """播放按钮"""
    duration: builtins.int
    """时长"""
    jump_url: builtins.str
    """跳转地址"""
    @property
    def badge_category(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """新角标，多个角标之前没有间距"""
    is_feature: builtins.bool
    """当前是否是pgc正片"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        cid: builtins.int = ...,
        season_id: builtins.int = ...,
        epid: builtins.int = ...,
        aid: builtins.int = ...,
        media_type: global___MediaType.ValueType = ...,
        sub_type: global___VideoSubType.ValueType = ...,
        is_preview: builtins.bool = ...,
        dimension: global___Dimension | None = ...,
        badge: collections.abc.Iterable[global___VideoBadge] | None = ...,
        can_play: builtins.bool = ...,
        season: global___PGCSeason | None = ...,
        play_icon: builtins.str = ...,
        duration: builtins.int = ...,
        jump_url: builtins.str = ...,
        badge_category: collections.abc.Iterable[global___VideoBadge] | None = ...,
        is_feature: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension", "season", b"season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "badge", b"badge", "badge_category", b"badge_category", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "dimension", b"dimension", "duration", b"duration", "epid", b"epid", "is_feature", b"is_feature", "is_preview", b"is_preview", "jump_url", b"jump_url", "media_type", b"media_type", "play_icon", b"play_icon", "season", b"season", "season_id", b"season_id", "sub_type", b"sub_type", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynPGC = MdlDynPGC

@typing_extensions.final
class MdlDynSubscription(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-订阅卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AD_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AD_TITLE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    TIPS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """卡片物料id"""
    ad_id: builtins.int
    """广告创意id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    ad_title: builtins.str
    """广告标题"""
    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
    tips: builtins.str
    """小提示"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        ad_id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        ad_title: builtins.str = ...,
        badge: global___VideoBadge | None = ...,
        tips: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_id", b"ad_id", "ad_title", b"ad_title", "badge", b"badge", "cover", b"cover", "id", b"id", "tips", b"tips", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynSubscription = MdlDynSubscription

@typing_extensions.final
class MdlDynSubscriptionNew(google.protobuf.message.Message):
    """动态新附加卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_FIELD_NUMBER: builtins.int
    DYN_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    DYN_LIVE_RCMD_FIELD_NUMBER: builtins.int
    style: global___MdlDynSubscriptionNewStyle.ValueType
    """样式类型"""
    @property
    def dyn_subscription(self) -> global___MdlDynSubscription:
        """"""
    @property
    def dyn_live_rcmd(self) -> global___MdlDynLiveRcmd:
        """直播推荐"""
    def __init__(
        self,
        *,
        style: global___MdlDynSubscriptionNewStyle.ValueType = ...,
        dyn_subscription: global___MdlDynSubscription | None = ...,
        dyn_live_rcmd: global___MdlDynLiveRcmd | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dyn_live_rcmd", b"dyn_live_rcmd", "dyn_subscription", b"dyn_subscription", "item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_live_rcmd", b"dyn_live_rcmd", "dyn_subscription", b"dyn_subscription", "item", b"item", "style", b"style"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["dyn_subscription", "dyn_live_rcmd"] | None: ...

global___MdlDynSubscriptionNew = MdlDynSubscriptionNew

@typing_extensions.final
class MdlDynUGCSeason(google.protobuf.message.Message):
    """动态列表渲染部分-UGC合集"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INLINEURL_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """秒开地址"""
    cover_left_text_1: builtins.str
    """视频封面展示项 1"""
    cover_left_text_2: builtins.str
    """视频封面展示项 2"""
    cover_left_text_3: builtins.str
    """封面视频展示项 3"""
    id: builtins.int
    """卡片物料id"""
    inlineURL: builtins.str
    """inline播放地址"""
    can_play: builtins.bool
    """是否能够自动播放"""
    play_icon: builtins.str
    """播放按钮"""
    avid: builtins.int
    """avid"""
    cid: builtins.int
    """cid"""
    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
    duration: builtins.int
    """时长"""
    jump_url: builtins.str
    """跳转地址"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        id: builtins.int = ...,
        inlineURL: builtins.str = ...,
        can_play: builtins.bool = ...,
        play_icon: builtins.str = ...,
        avid: builtins.int = ...,
        cid: builtins.int = ...,
        dimension: global___Dimension | None = ...,
        duration: builtins.int = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avid", b"avid", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "dimension", b"dimension", "duration", b"duration", "id", b"id", "inlineURL", b"inlineURL", "jump_url", b"jump_url", "play_icon", b"play_icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynUGCSeason = MdlDynUGCSeason

@typing_extensions.final
class MixUpListItem(google.protobuf.message.Message):
    """查看更多-列表单条数据"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    SPECIAL_ATTENTION_FIELD_NUMBER: builtins.int
    REDDOT_STATE_FIELD_NUMBER: builtins.int
    LIVE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""
    special_attention: builtins.int
    """特别关注
    0:否 1:是
    """
    reddot_state: builtins.int
    """小红点状态
    0:没有 1:有
    """
    @property
    def live_info(self) -> global___MixUpListLiveItem:
        """直播信息"""
    name: builtins.str
    """昵称"""
    face: builtins.str
    """头像"""
    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        special_attention: builtins.int = ...,
        reddot_state: builtins.int = ...,
        live_info: global___MixUpListLiveItem | None = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        official: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live_info", b"live_info", "official", b"official", "relation", b"relation", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "live_info", b"live_info", "name", b"name", "official", b"official", "reddot_state", b"reddot_state", "relation", b"relation", "special_attention", b"special_attention", "uid", b"uid", "vip", b"vip"]) -> None: ...

global___MixUpListItem = MixUpListItem

@typing_extensions.final
class MixUpListLiveItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    status: builtins.bool
    """直播状态
    0:未直播 1:直播中
    """
    room_id: builtins.int
    """房间号"""
    uri: builtins.str
    """跳转地址"""
    def __init__(
        self,
        *,
        status: builtins.bool = ...,
        room_id: builtins.int = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_id", b"room_id", "status", b"status", "uri", b"uri"]) -> None: ...

global___MixUpListLiveItem = MixUpListLiveItem

@typing_extensions.final
class Module(google.protobuf.message.Message):
    """动态模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_TYPE_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FIELD_NUMBER: builtins.int
    MODULE_DISPUTE_FIELD_NUMBER: builtins.int
    MODULE_DESC_FIELD_NUMBER: builtins.int
    MODULE_DYNAMIC_FIELD_NUMBER: builtins.int
    MODULE_LIKEUSER_FIELD_NUMBER: builtins.int
    MODULE_EXTEND_FIELD_NUMBER: builtins.int
    MODULE_ADDITIONAL_FIELD_NUMBER: builtins.int
    MODULE_STAT_FIELD_NUMBER: builtins.int
    MODULE_FOLD_FIELD_NUMBER: builtins.int
    MODULE_COMMENT_FIELD_NUMBER: builtins.int
    MODULE_INTERACTION_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FORWARD_FIELD_NUMBER: builtins.int
    MODULE_AD_FIELD_NUMBER: builtins.int
    MODULE_BANNER_FIELD_NUMBER: builtins.int
    MODULE_ITEM_NULL_FIELD_NUMBER: builtins.int
    MODULE_SHARE_INFO_FIELD_NUMBER: builtins.int
    MODULE_RECOMMEND_FIELD_NUMBER: builtins.int
    MODULE_TOP_FIELD_NUMBER: builtins.int
    MODULE_BUTTOM_FIELD_NUMBER: builtins.int
    MODULE_STAT_FORWARD_FIELD_NUMBER: builtins.int
    module_type: global___DynModuleType.ValueType
    """类型"""
    @property
    def module_author(self) -> global___ModuleAuthor:
        """用户模块 1"""
    @property
    def module_dispute(self) -> global___ModuleDispute:
        """争议黄条模块 2"""
    @property
    def module_desc(self) -> global___ModuleDesc:
        """动态正文模块 3"""
    @property
    def module_dynamic(self) -> global___ModuleDynamic:
        """动态卡模块 4"""
    @property
    def module_likeUser(self) -> global___ModuleLikeUser:
        """点赞外露(废弃)"""
    @property
    def module_extend(self) -> global___ModuleExtend:
        """小卡模块 6"""
    @property
    def module_additional(self) -> global___ModuleAdditional:
        """大卡模块 5"""
    @property
    def module_stat(self) -> global___ModuleStat:
        """计数模块 8"""
    @property
    def module_fold(self) -> global___ModuleFold:
        """折叠模块 9"""
    @property
    def module_comment(self) -> global___ModuleComment:
        """评论外露(废弃)"""
    @property
    def module_interaction(self) -> global___ModuleInteraction:
        """外露交互模块(点赞、评论) 7"""
    @property
    def module_author_forward(self) -> global___ModuleAuthorForward:
        """转发卡-原卡用户模块"""
    @property
    def module_ad(self) -> global___ModuleAd:
        """广告卡"""
    @property
    def module_banner(self) -> global___ModuleBanner:
        """通栏"""
    @property
    def module_item_null(self) -> global___ModuleItemNull:
        """获取物料失败"""
    @property
    def module_share_info(self) -> global___ModuleShareInfo:
        """分享组件"""
    @property
    def module_recommend(self) -> global___ModuleRecommend:
        """相关推荐模块"""
    @property
    def module_top(self) -> global___ModuleTop:
        """顶部模块"""
    @property
    def module_buttom(self) -> global___ModuleButtom:
        """底部模块"""
    @property
    def module_stat_forward(self) -> global___ModuleStat:
        """转发卡计数模块"""
    def __init__(
        self,
        *,
        module_type: global___DynModuleType.ValueType = ...,
        module_author: global___ModuleAuthor | None = ...,
        module_dispute: global___ModuleDispute | None = ...,
        module_desc: global___ModuleDesc | None = ...,
        module_dynamic: global___ModuleDynamic | None = ...,
        module_likeUser: global___ModuleLikeUser | None = ...,
        module_extend: global___ModuleExtend | None = ...,
        module_additional: global___ModuleAdditional | None = ...,
        module_stat: global___ModuleStat | None = ...,
        module_fold: global___ModuleFold | None = ...,
        module_comment: global___ModuleComment | None = ...,
        module_interaction: global___ModuleInteraction | None = ...,
        module_author_forward: global___ModuleAuthorForward | None = ...,
        module_ad: global___ModuleAd | None = ...,
        module_banner: global___ModuleBanner | None = ...,
        module_item_null: global___ModuleItemNull | None = ...,
        module_share_info: global___ModuleShareInfo | None = ...,
        module_recommend: global___ModuleRecommend | None = ...,
        module_top: global___ModuleTop | None = ...,
        module_buttom: global___ModuleButtom | None = ...,
        module_stat_forward: global___ModuleStat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_ad", b"module_ad", "module_additional", b"module_additional", "module_author", b"module_author", "module_author_forward", b"module_author_forward", "module_banner", b"module_banner", "module_buttom", b"module_buttom", "module_comment", b"module_comment", "module_desc", b"module_desc", "module_dispute", b"module_dispute", "module_dynamic", b"module_dynamic", "module_extend", b"module_extend", "module_fold", b"module_fold", "module_interaction", b"module_interaction", "module_item", b"module_item", "module_item_null", b"module_item_null", "module_likeUser", b"module_likeUser", "module_recommend", b"module_recommend", "module_share_info", b"module_share_info", "module_stat", b"module_stat", "module_stat_forward", b"module_stat_forward", "module_top", b"module_top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_ad", b"module_ad", "module_additional", b"module_additional", "module_author", b"module_author", "module_author_forward", b"module_author_forward", "module_banner", b"module_banner", "module_buttom", b"module_buttom", "module_comment", b"module_comment", "module_desc", b"module_desc", "module_dispute", b"module_dispute", "module_dynamic", b"module_dynamic", "module_extend", b"module_extend", "module_fold", b"module_fold", "module_interaction", b"module_interaction", "module_item", b"module_item", "module_item_null", b"module_item_null", "module_likeUser", b"module_likeUser", "module_recommend", b"module_recommend", "module_share_info", b"module_share_info", "module_stat", b"module_stat", "module_stat_forward", b"module_stat_forward", "module_top", b"module_top", "module_type", b"module_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["module_item", b"module_item"]) -> typing_extensions.Literal["module_author", "module_dispute", "module_desc", "module_dynamic", "module_likeUser", "module_extend", "module_additional", "module_stat", "module_fold", "module_comment", "module_interaction", "module_author_forward", "module_ad", "module_banner", "module_item_null", "module_share_info", "module_recommend", "module_top", "module_buttom", "module_stat_forward"] | None: ...

global___Module = Module

@typing_extensions.final
class ModuleAd(google.protobuf.message.Message):
    """动态列表-用户模块-广告卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_CONTENT_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FIELD_NUMBER: builtins.int
    @property
    def source_content(self) -> google.protobuf.any_pb2.Any:
        """广告透传信息"""
    @property
    def module_author(self) -> global___ModuleAuthor:
        """用户模块"""
    def __init__(
        self,
        *,
        source_content: google.protobuf.any_pb2.Any | None = ...,
        module_author: global___ModuleAuthor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_author", b"module_author", "source_content", b"source_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_author", b"module_author", "source_content", b"source_content"]) -> None: ...

global___ModuleAd = ModuleAd

@typing_extensions.final
class ModuleAdditional(google.protobuf.message.Message):
    """动态-附加卡模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    PGC_FIELD_NUMBER: builtins.int
    GOODS_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    COMMON_FIELD_NUMBER: builtins.int
    ESPORT_FIELD_NUMBER: builtins.int
    VOTE2_FIELD_NUMBER: builtins.int
    UGC_FIELD_NUMBER: builtins.int
    UP_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    type: global___AdditionalType.ValueType
    """类型"""
    @property
    def pgc(self) -> global___AdditionalPGC:
        """废弃"""
    @property
    def goods(self) -> global___AdditionGoods:
        """"""
    @property
    def vote(self) -> global___AdditionVote:
        """废弃"""
    @property
    def common(self) -> global___AdditionCommon:
        """"""
    @property
    def esport(self) -> global___AdditionEsport:
        """"""
    @property
    def vote2(self) -> global___AdditionVote2:
        """投票"""
    @property
    def ugc(self) -> global___AdditionUgc:
        """"""
    @property
    def up(self) -> global___AdditionUP:
        """up主预约发布卡"""
    rid: builtins.int
    """附加卡物料ID"""
    def __init__(
        self,
        *,
        type: global___AdditionalType.ValueType = ...,
        pgc: global___AdditionalPGC | None = ...,
        goods: global___AdditionGoods | None = ...,
        vote: global___AdditionVote | None = ...,
        common: global___AdditionCommon | None = ...,
        esport: global___AdditionEsport | None = ...,
        vote2: global___AdditionVote2 | None = ...,
        ugc: global___AdditionUgc | None = ...,
        up: global___AdditionUP | None = ...,
        rid: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["common", b"common", "esport", b"esport", "goods", b"goods", "item", b"item", "pgc", b"pgc", "ugc", b"ugc", "up", b"up", "vote", b"vote", "vote2", b"vote2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common", b"common", "esport", b"esport", "goods", b"goods", "item", b"item", "pgc", b"pgc", "rid", b"rid", "type", b"type", "ugc", b"ugc", "up", b"up", "vote", b"vote", "vote2", b"vote2"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["pgc", "goods", "vote", "common", "esport", "vote2", "ugc", "up"] | None: ...

global___ModuleAdditional = ModuleAdditional

@typing_extensions.final
class ModuleAuthor(google.protobuf.message.Message):
    """动态-发布人模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    PTIME_LABEL_TEXT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    DECORATE_CARD_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TP_LIST_FIELD_NUMBER: builtins.int
    BADGE_TYPE_FIELD_NUMBER: builtins.int
    BADGE_BUTTON_FIELD_NUMBER: builtins.int
    ATTEND_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    ptime_label_text: builtins.str
    """时间标签"""
    @property
    def author(self) -> global___UserInfo:
        """用户详情"""
    @property
    def decorate_card(self) -> global___DecorateCard:
        """装扮卡片"""
    uri: builtins.str
    """点击跳转链接"""
    @property
    def tp_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """右侧操作区域 - 三点样式"""
    badge_type: global___ModuleAuthorBadgeType.ValueType
    """右侧操作区域样式枚举"""
    @property
    def badge_button(self) -> global___ModuleAuthorBadgeButton:
        """右侧操作区域 - 按钮样式"""
    attend: builtins.int
    """是否关注
    1:关注 0:不关注 默认0，注：点赞列表使用，其他场景不使用该字段
    """
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    @property
    def weight(self) -> global___Weight:
        """右侧操作区域 - 提权样式"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        ptime_label_text: builtins.str = ...,
        author: global___UserInfo | None = ...,
        decorate_card: global___DecorateCard | None = ...,
        uri: builtins.str = ...,
        tp_list: collections.abc.Iterable[global___ThreePointItem] | None = ...,
        badge_type: global___ModuleAuthorBadgeType.ValueType = ...,
        badge_button: global___ModuleAuthorBadgeButton | None = ...,
        attend: builtins.int = ...,
        relation: global___Relation | None = ...,
        weight: global___Weight | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "badge_button", b"badge_button", "decorate_card", b"decorate_card", "relation", b"relation", "weight", b"weight"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attend", b"attend", "author", b"author", "badge_button", b"badge_button", "badge_type", b"badge_type", "decorate_card", b"decorate_card", "mid", b"mid", "ptime_label_text", b"ptime_label_text", "relation", b"relation", "tp_list", b"tp_list", "uri", b"uri", "weight", b"weight"]) -> None: ...

global___ModuleAuthor = ModuleAuthor

@typing_extensions.final
class ModuleAuthorBadgeButton(google.protobuf.message.Message):
    """动态列表渲染部分-用户模块-按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """图标"""
    title: builtins.str
    """文案"""
    state: builtins.int
    """状态"""
    id: builtins.int
    """物料ID"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        state: builtins.int = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "id", b"id", "state", b"state", "title", b"title"]) -> None: ...

global___ModuleAuthorBadgeButton = ModuleAuthorBadgeButton

@typing_extensions.final
class ModuleAuthorForward(google.protobuf.message.Message):
    """动态列表-用户模块-转发模板"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    PTIME_LABEL_TEXT_FIELD_NUMBER: builtins.int
    SHOW_FOLLOW_FIELD_NUMBER: builtins.int
    FACE_URL_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    TP_LIST_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleAuthorForwardTitle]:
        """展示标题"""
    url: builtins.str
    """源卡片跳转链接"""
    uid: builtins.int
    """用户uid"""
    ptime_label_text: builtins.str
    """时间标签"""
    show_follow: builtins.bool
    """是否展示关注"""
    face_url: builtins.str
    """源up主头像"""
    @property
    def relation(self) -> global___Relation:
        """双向关系"""
    @property
    def tp_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """右侧操作区域 - 三点样式"""
    def __init__(
        self,
        *,
        title: collections.abc.Iterable[global___ModuleAuthorForwardTitle] | None = ...,
        url: builtins.str = ...,
        uid: builtins.int = ...,
        ptime_label_text: builtins.str = ...,
        show_follow: builtins.bool = ...,
        face_url: builtins.str = ...,
        relation: global___Relation | None = ...,
        tp_list: collections.abc.Iterable[global___ThreePointItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face_url", b"face_url", "ptime_label_text", b"ptime_label_text", "relation", b"relation", "show_follow", b"show_follow", "title", b"title", "tp_list", b"tp_list", "uid", b"uid", "url", b"url"]) -> None: ...

global___ModuleAuthorForward = ModuleAuthorForward

@typing_extensions.final
class ModuleAuthorForwardTitle(google.protobuf.message.Message):
    """动态列表-用户模块-转发模板-title部分"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文案"""
    url: builtins.str
    """跳转链接"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "url", b"url"]) -> None: ...

global___ModuleAuthorForwardTitle = ModuleAuthorForwardTitle

@typing_extensions.final
class ModuleBanner(google.protobuf.message.Message):
    """动态列表-通栏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DISLIKE_TEXT_FIELD_NUMBER: builtins.int
    DISLIKE_ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """模块标题"""
    type: global___ModuleBannerType.ValueType
    """卡片类型"""
    @property
    def user(self) -> global___ModuleBannerUser: ...
    dislike_text: builtins.str
    """不感兴趣文案"""
    dislike_icon: builtins.str
    """不感兴趣图标"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        type: global___ModuleBannerType.ValueType = ...,
        user: global___ModuleBannerUser | None = ...,
        dislike_text: builtins.str = ...,
        dislike_icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike_icon", b"dislike_icon", "dislike_text", b"dislike_text", "item", b"item", "title", b"title", "type", b"type", "user", b"user"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["user"] | None: ...

global___ModuleBanner = ModuleBanner

@typing_extensions.final
class ModuleBannerUser(google.protobuf.message.Message):
    """动态通栏-用户"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleBannerUserItem]:
        """卡片列表"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___ModuleBannerUserItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___ModuleBannerUser = ModuleBannerUser

@typing_extensions.final
class ModuleBannerUserItem(google.protobuf.message.Message):
    """动态通栏-推荐用户卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    face: builtins.str
    """up主头像"""
    name: builtins.str
    """up主昵称"""
    uid: builtins.int
    """up主uid"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
    label: builtins.str
    """标签信息"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    uri: builtins.str
    """跳转地址"""
    def __init__(
        self,
        *,
        face: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.int = ...,
        live_state: global___LiveState.ValueType = ...,
        official: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        label: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "official", b"official", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "face", b"face", "label", b"label", "live_state", b"live_state", "name", b"name", "official", b"official", "uid", b"uid", "uri", b"uri", "vip", b"vip"]) -> None: ...

global___ModuleBannerUserItem = ModuleBannerUserItem

@typing_extensions.final
class ModuleButtom(google.protobuf.message.Message):
    """底部模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_STAT_FIELD_NUMBER: builtins.int
    @property
    def module_stat(self) -> global___ModuleStat:
        """计数模块"""
    def __init__(
        self,
        *,
        module_stat: global___ModuleStat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_stat", b"module_stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_stat", b"module_stat"]) -> None: ...

global___ModuleButtom = ModuleButtom

@typing_extensions.final
class ModuleComment(google.protobuf.message.Message):
    """评论外露模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CMTSHOWITEM_FIELD_NUMBER: builtins.int
    @property
    def cmtShowItem(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CmtShowItem]:
        """评论外露展示项"""
    def __init__(
        self,
        *,
        cmtShowItem: collections.abc.Iterable[global___CmtShowItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cmtShowItem", b"cmtShowItem"]) -> None: ...

global___ModuleComment = ModuleComment

@typing_extensions.final
class ModuleDesc(google.protobuf.message.Message):
    """动态-描述文字模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC_FIELD_NUMBER: builtins.int
    JUMP_URI_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    @property
    def desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """描述信息(已按高亮拆分)"""
    jump_uri: builtins.str
    """点击跳转链接"""
    text: builtins.str
    """文本原本"""
    def __init__(
        self,
        *,
        desc: collections.abc.Iterable[global___Description] | None = ...,
        jump_uri: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "jump_uri", b"jump_uri", "text", b"text"]) -> None: ...

global___ModuleDesc = ModuleDesc

@typing_extensions.final
class ModuleDescGoods(google.protobuf.message.Message):
    """正文商品卡参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    OPEN_WHITE_LIST_FIELD_NUMBER: builtins.int
    USER_WEB_V2_FIELD_NUMBER: builtins.int
    AD_MARK_FIELD_NUMBER: builtins.int
    SCHEMA_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    source_type: builtins.int
    """商品类型
    1:淘宝 2:会员购
    """
    jump_url: builtins.str
    """跳转链接"""
    schema_url: builtins.str
    """schema_url"""
    item_id: builtins.int
    """item_id"""
    @property
    def open_white_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """open_white_list"""
    user_web_v2: builtins.bool
    """use_web_v2"""
    ad_mark: builtins.str
    """ad mark"""
    schema_package_name: builtins.str
    """schemaPackageName(Android用)"""
    def __init__(
        self,
        *,
        source_type: builtins.int = ...,
        jump_url: builtins.str = ...,
        schema_url: builtins.str = ...,
        item_id: builtins.int = ...,
        open_white_list: collections.abc.Iterable[builtins.str] | None = ...,
        user_web_v2: builtins.bool = ...,
        ad_mark: builtins.str = ...,
        schema_package_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_mark", b"ad_mark", "item_id", b"item_id", "jump_url", b"jump_url", "open_white_list", b"open_white_list", "schema_package_name", b"schema_package_name", "schema_url", b"schema_url", "source_type", b"source_type", "user_web_v2", b"user_web_v2"]) -> None: ...

global___ModuleDescGoods = ModuleDescGoods

@typing_extensions.final
class ModuleDispute(google.protobuf.message.Message):
    """动态-争议小黄条模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    desc: builtins.str
    """描述内容"""
    uri: builtins.str
    """跳转链接"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "title", b"title", "uri", b"uri"]) -> None: ...

global___ModuleDispute = ModuleDispute

@typing_extensions.final
class ModuleDynamic(google.protobuf.message.Message):
    """动态-详情模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DYN_ARCHIVE_FIELD_NUMBER: builtins.int
    DYN_PGC_FIELD_NUMBER: builtins.int
    DYN_COUR_SEASON_FIELD_NUMBER: builtins.int
    DYN_COUR_BATCH_FIELD_NUMBER: builtins.int
    DYN_FORWARD_FIELD_NUMBER: builtins.int
    DYN_DRAW_FIELD_NUMBER: builtins.int
    DYN_ARTICLE_FIELD_NUMBER: builtins.int
    DYN_MUSIC_FIELD_NUMBER: builtins.int
    DYN_COMMON_FIELD_NUMBER: builtins.int
    DYN_COMMON_LIVE_FIELD_NUMBER: builtins.int
    DYN_MEDIALIST_FIELD_NUMBER: builtins.int
    DYN_APPLET_FIELD_NUMBER: builtins.int
    DYN_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    DYN_LIVE_RCMD_FIELD_NUMBER: builtins.int
    DYN_UGC_SEASON_FIELD_NUMBER: builtins.int
    DYN_SUBSCRIPTION_NEW_FIELD_NUMBER: builtins.int
    type: global___ModuleDynamicType.ValueType
    """类型"""
    @property
    def dyn_archive(self) -> global___MdlDynArchive:
        """稿件"""
    @property
    def dyn_pgc(self) -> global___MdlDynPGC:
        """pgc"""
    @property
    def dyn_cour_season(self) -> global___MdlDynCourSeason:
        """付费课程-系列"""
    @property
    def dyn_cour_batch(self) -> global___MdlDynCourBatch:
        """付费课程-批次"""
    @property
    def dyn_forward(self) -> global___MdlDynForward:
        """转发卡"""
    @property
    def dyn_draw(self) -> global___MdlDynDraw:
        """图文"""
    @property
    def dyn_article(self) -> global___MdlDynArticle:
        """专栏"""
    @property
    def dyn_music(self) -> global___MdlDynMusic:
        """音频"""
    @property
    def dyn_common(self) -> global___MdlDynCommon:
        """通用卡方"""
    @property
    def dyn_common_live(self) -> global___MdlDynLive:
        """直播卡"""
    @property
    def dyn_medialist(self) -> global___MdlDynMedialist:
        """播单"""
    @property
    def dyn_applet(self) -> global___MdlDynApplet:
        """小程序卡"""
    @property
    def dyn_subscription(self) -> global___MdlDynSubscription:
        """订阅卡"""
    @property
    def dyn_live_rcmd(self) -> global___MdlDynLiveRcmd:
        """直播推荐卡"""
    @property
    def dyn_ugc_season(self) -> global___MdlDynUGCSeason:
        """UGC合集"""
    @property
    def dyn_subscription_new(self) -> global___MdlDynSubscriptionNew:
        """订阅卡"""
    def __init__(
        self,
        *,
        type: global___ModuleDynamicType.ValueType = ...,
        dyn_archive: global___MdlDynArchive | None = ...,
        dyn_pgc: global___MdlDynPGC | None = ...,
        dyn_cour_season: global___MdlDynCourSeason | None = ...,
        dyn_cour_batch: global___MdlDynCourBatch | None = ...,
        dyn_forward: global___MdlDynForward | None = ...,
        dyn_draw: global___MdlDynDraw | None = ...,
        dyn_article: global___MdlDynArticle | None = ...,
        dyn_music: global___MdlDynMusic | None = ...,
        dyn_common: global___MdlDynCommon | None = ...,
        dyn_common_live: global___MdlDynLive | None = ...,
        dyn_medialist: global___MdlDynMedialist | None = ...,
        dyn_applet: global___MdlDynApplet | None = ...,
        dyn_subscription: global___MdlDynSubscription | None = ...,
        dyn_live_rcmd: global___MdlDynLiveRcmd | None = ...,
        dyn_ugc_season: global___MdlDynUGCSeason | None = ...,
        dyn_subscription_new: global___MdlDynSubscriptionNew | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dyn_applet", b"dyn_applet", "dyn_archive", b"dyn_archive", "dyn_article", b"dyn_article", "dyn_common", b"dyn_common", "dyn_common_live", b"dyn_common_live", "dyn_cour_batch", b"dyn_cour_batch", "dyn_cour_season", b"dyn_cour_season", "dyn_draw", b"dyn_draw", "dyn_forward", b"dyn_forward", "dyn_live_rcmd", b"dyn_live_rcmd", "dyn_medialist", b"dyn_medialist", "dyn_music", b"dyn_music", "dyn_pgc", b"dyn_pgc", "dyn_subscription", b"dyn_subscription", "dyn_subscription_new", b"dyn_subscription_new", "dyn_ugc_season", b"dyn_ugc_season", "module_item", b"module_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_applet", b"dyn_applet", "dyn_archive", b"dyn_archive", "dyn_article", b"dyn_article", "dyn_common", b"dyn_common", "dyn_common_live", b"dyn_common_live", "dyn_cour_batch", b"dyn_cour_batch", "dyn_cour_season", b"dyn_cour_season", "dyn_draw", b"dyn_draw", "dyn_forward", b"dyn_forward", "dyn_live_rcmd", b"dyn_live_rcmd", "dyn_medialist", b"dyn_medialist", "dyn_music", b"dyn_music", "dyn_pgc", b"dyn_pgc", "dyn_subscription", b"dyn_subscription", "dyn_subscription_new", b"dyn_subscription_new", "dyn_ugc_season", b"dyn_ugc_season", "module_item", b"module_item", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["module_item", b"module_item"]) -> typing_extensions.Literal["dyn_archive", "dyn_pgc", "dyn_cour_season", "dyn_cour_batch", "dyn_forward", "dyn_draw", "dyn_article", "dyn_music", "dyn_common", "dyn_common_live", "dyn_medialist", "dyn_applet", "dyn_subscription", "dyn_live_rcmd", "dyn_ugc_season", "dyn_subscription_new"] | None: ...

global___ModuleDynamic = ModuleDynamic

@typing_extensions.final
class ModuleExtend(google.protobuf.message.Message):
    """动态-小卡模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTEND_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    @property
    def extend(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleExtendItem]:
        """详情"""
    uri: builtins.str
    """模块整体跳转uri
    废弃
    """
    def __init__(
        self,
        *,
        extend: collections.abc.Iterable[global___ModuleExtendItem] | None = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extend", b"extend", "uri", b"uri"]) -> None: ...

global___ModuleExtend = ModuleExtend

@typing_extensions.final
class ModuleExtendItem(google.protobuf.message.Message):
    """动态-拓展小卡模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    EXT_INFO_TOPIC_FIELD_NUMBER: builtins.int
    EXT_INFO_LBS_FIELD_NUMBER: builtins.int
    EXT_INFO_HOT_FIELD_NUMBER: builtins.int
    EXT_INFO_GAME_FIELD_NUMBER: builtins.int
    EXT_INFO_COMMON_FIELD_NUMBER: builtins.int
    EXT_INFO_OGV_FIELD_NUMBER: builtins.int
    type: global___DynExtendType.ValueType
    """类型"""
    @property
    def ext_info_topic(self) -> global___ExtInfoTopic:
        """废弃"""
    @property
    def ext_info_lbs(self) -> global___ExtInfoLBS:
        """废弃"""
    @property
    def ext_info_hot(self) -> global___ExtInfoHot:
        """废弃"""
    @property
    def ext_info_game(self) -> global___ExtInfoGame:
        """废弃"""
    @property
    def ext_info_common(self) -> global___ExtInfoCommon:
        """"""
    @property
    def ext_info_ogv(self) -> global___ExtInfoOGV:
        """"""
    def __init__(
        self,
        *,
        type: global___DynExtendType.ValueType = ...,
        ext_info_topic: global___ExtInfoTopic | None = ...,
        ext_info_lbs: global___ExtInfoLBS | None = ...,
        ext_info_hot: global___ExtInfoHot | None = ...,
        ext_info_game: global___ExtInfoGame | None = ...,
        ext_info_common: global___ExtInfoCommon | None = ...,
        ext_info_ogv: global___ExtInfoOGV | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ext_info_common", b"ext_info_common", "ext_info_game", b"ext_info_game", "ext_info_hot", b"ext_info_hot", "ext_info_lbs", b"ext_info_lbs", "ext_info_ogv", b"ext_info_ogv", "ext_info_topic", b"ext_info_topic", "extend", b"extend"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ext_info_common", b"ext_info_common", "ext_info_game", b"ext_info_game", "ext_info_hot", b"ext_info_hot", "ext_info_lbs", b"ext_info_lbs", "ext_info_ogv", b"ext_info_ogv", "ext_info_topic", b"ext_info_topic", "extend", b"extend", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["extend", b"extend"]) -> typing_extensions.Literal["ext_info_topic", "ext_info_lbs", "ext_info_hot", "ext_info_game", "ext_info_common", "ext_info_ogv"] | None: ...

global___ModuleExtendItem = ModuleExtendItem

@typing_extensions.final
class ModuleFold(google.protobuf.message.Message):
    """动态-折叠模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLD_TYPE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    FOLD_IDS_FIELD_NUMBER: builtins.int
    FOLD_USERS_FIELD_NUMBER: builtins.int
    fold_type: global___FoldType.ValueType
    """折叠分类"""
    text: builtins.str
    """折叠文案"""
    fold_ids: builtins.str
    """被折叠的动态"""
    @property
    def fold_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserInfo]:
        """被折叠的用户信息"""
    def __init__(
        self,
        *,
        fold_type: global___FoldType.ValueType = ...,
        text: builtins.str = ...,
        fold_ids: builtins.str = ...,
        fold_users: collections.abc.Iterable[global___UserInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fold_ids", b"fold_ids", "fold_type", b"fold_type", "fold_users", b"fold_users", "text", b"text"]) -> None: ...

global___ModuleFold = ModuleFold

@typing_extensions.final
class ModuleInteraction(google.protobuf.message.Message):
    """外露交互模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERACTION_ITEM_FIELD_NUMBER: builtins.int
    @property
    def interaction_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InteractionItem]:
        """外露交互模块"""
    def __init__(
        self,
        *,
        interaction_item: collections.abc.Iterable[global___InteractionItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interaction_item", b"interaction_item"]) -> None: ...

global___ModuleInteraction = ModuleInteraction

@typing_extensions.final
class ModuleItemNull(google.protobuf.message.Message):
    """获取物料失败模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """图标"""
    text: builtins.str
    """文案"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "text", b"text"]) -> None: ...

global___ModuleItemNull = ModuleItemNull

@typing_extensions.final
class ModuleLikeUser(google.protobuf.message.Message):
    """动态-点赞用户模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_USERS_FIELD_NUMBER: builtins.int
    DISPLAY_TEXT_FIELD_NUMBER: builtins.int
    @property
    def like_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LikeUser]:
        """点赞用户"""
    display_text: builtins.str
    """文案"""
    def __init__(
        self,
        *,
        like_users: collections.abc.Iterable[global___LikeUser] | None = ...,
        display_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_text", b"display_text", "like_users", b"like_users"]) -> None: ...

global___ModuleLikeUser = ModuleLikeUser

@typing_extensions.final
class ModuleRecommend(google.protobuf.message.Message):
    """相关推荐模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_TITLE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    AD_FIELD_NUMBER: builtins.int
    module_title: builtins.str
    """模块标题"""
    image: builtins.str
    """图片"""
    tag: builtins.str
    """标签"""
    title: builtins.str
    """标题"""
    jump_url: builtins.str
    """跳转链接"""
    @property
    def ad(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """序列化的广告信息"""
    def __init__(
        self,
        *,
        module_title: builtins.str = ...,
        image: builtins.str = ...,
        tag: builtins.str = ...,
        title: builtins.str = ...,
        jump_url: builtins.str = ...,
        ad: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad", b"ad", "image", b"image", "jump_url", b"jump_url", "module_title", b"module_title", "tag", b"tag", "title", b"title"]) -> None: ...

global___ModuleRecommend = ModuleRecommend

@typing_extensions.final
class ModuleShareInfo(google.protobuf.message.Message):
    """分享模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SHARE_CHANNELS_FIELD_NUMBER: builtins.int
    SHARE_ORIGIN_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """展示标题"""
    @property
    def share_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareChannel]:
        """分享组件列表"""
    share_origin: builtins.str
    """share_origin"""
    oid: builtins.str
    """业务id"""
    sid: builtins.str
    """sid"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        share_channels: collections.abc.Iterable[global___ShareChannel] | None = ...,
        share_origin: builtins.str = ...,
        oid: builtins.str = ...,
        sid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "share_channels", b"share_channels", "share_origin", b"share_origin", "sid", b"sid", "title", b"title"]) -> None: ...

global___ModuleShareInfo = ModuleShareInfo

@typing_extensions.final
class ModuleStat(google.protobuf.message.Message):
    """动态-计数模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOST_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    LIKE_INFO_FIELD_NUMBER: builtins.int
    NO_COMMENT_FIELD_NUMBER: builtins.int
    NO_FORWARD_FIELD_NUMBER: builtins.int
    REPLY_URL_FIELD_NUMBER: builtins.int
    NO_COMMENT_TEXT_FIELD_NUMBER: builtins.int
    NO_FORWARD_TEXT_FIELD_NUMBER: builtins.int
    repost: builtins.int
    """转发数"""
    like: builtins.int
    """点赞数"""
    reply: builtins.int
    """评论数"""
    @property
    def like_info(self) -> global___LikeInfo:
        """点赞拓展信息"""
    no_comment: builtins.bool
    """禁评"""
    no_forward: builtins.bool
    """禁转"""
    reply_url: builtins.str
    """点击评论跳转链接"""
    no_comment_text: builtins.str
    """禁评文案"""
    no_forward_text: builtins.str
    """禁转文案"""
    def __init__(
        self,
        *,
        repost: builtins.int = ...,
        like: builtins.int = ...,
        reply: builtins.int = ...,
        like_info: global___LikeInfo | None = ...,
        no_comment: builtins.bool = ...,
        no_forward: builtins.bool = ...,
        reply_url: builtins.str = ...,
        no_comment_text: builtins.str = ...,
        no_forward_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["like_info", b"like_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["like", b"like", "like_info", b"like_info", "no_comment", b"no_comment", "no_comment_text", b"no_comment_text", "no_forward", b"no_forward", "no_forward_text", b"no_forward_text", "reply", b"reply", "reply_url", b"reply_url", "repost", b"repost"]) -> None: ...

global___ModuleStat = ModuleStat

@typing_extensions.final
class ModuleTop(google.protobuf.message.Message):
    """顶部模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TP_LIST_FIELD_NUMBER: builtins.int
    @property
    def tp_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """三点模块"""
    def __init__(
        self,
        *,
        tp_list: collections.abc.Iterable[global___ThreePointItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tp_list", b"tp_list"]) -> None: ...

global___ModuleTop = ModuleTop

@typing_extensions.final
class Nameplate(google.protobuf.message.Message):
    """认证名牌"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_SMALL_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    nid: builtins.int
    """nid"""
    name: builtins.str
    """名称"""
    image: builtins.str
    """图片地址"""
    image_small: builtins.str
    """小图地址"""
    level: builtins.str
    """等级"""
    condition: builtins.str
    """获取条件"""
    def __init__(
        self,
        *,
        nid: builtins.int = ...,
        name: builtins.str = ...,
        image: builtins.str = ...,
        image_small: builtins.str = ...,
        level: builtins.str = ...,
        condition: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "image", b"image", "image_small", b"image_small", "level", b"level", "name", b"name", "nid", b"nid"]) -> None: ...

global___Nameplate = Nameplate

@typing_extensions.final
class NewEP(google.protobuf.message.Message):
    """最新ep"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INDEX_SHOW_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    id: builtins.int
    """最新话epid"""
    index_show: builtins.str
    """更新至XX话"""
    cover: builtins.str
    """更新剧集的封面"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        index_show: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "id", b"id", "index_show", b"index_show"]) -> None: ...

global___NewEP = NewEP

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """空响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class NoReq(google.protobuf.message.Message):
    """空请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReq = NoReq

@typing_extensions.final
class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    IS_ATTEN_FIELD_NUMBER: builtins.int
    type: builtins.int
    """127:未认证 0:个人 1:机构"""
    desc: builtins.str
    """认证描述"""
    is_atten: builtins.int
    """是否关注"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        desc: builtins.str = ...,
        is_atten: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "is_atten", b"is_atten", "type", b"type"]) -> None: ...

global___OfficialVerify = OfficialVerify

@typing_extensions.final
class PGCSeason(google.protobuf.message.Message):
    """PGC单季信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_FINISH_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    is_finish: builtins.int
    """是否完结"""
    title: builtins.str
    """标题"""
    type: builtins.int
    """类型"""
    def __init__(
        self,
        *,
        is_finish: builtins.int = ...,
        title: builtins.str = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_finish", b"is_finish", "title", b"title", "type", b"type"]) -> None: ...

global___PGCSeason = PGCSeason

@typing_extensions.final
class PlayerArgs(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """"""
    fnver: builtins.int
    """"""
    fnval: builtins.int
    """"""
    force_host: builtins.int
    """"""
    def __init__(
        self,
        *,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "qn", b"qn"]) -> None: ...

global___PlayerArgs = PlayerArgs

@typing_extensions.final
class PlayurlParam(google.protobuf.message.Message):
    """秒开通用参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """流版本"""
    fnval: builtins.int
    """流类型"""
    force_host: builtins.int
    """是否强制使用域名"""
    fourk: builtins.int
    """是否4k"""
    def __init__(
        self,
        *,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "qn", b"qn"]) -> None: ...

global___PlayurlParam = PlayurlParam

@typing_extensions.final
class RcmdUPsParam(google.protobuf.message.Message):
    """推荐up主入参"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISLIKE_TS_FIELD_NUMBER: builtins.int
    dislike_ts: builtins.int
    def __init__(
        self,
        *,
        dislike_ts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike_ts", b"dislike_ts"]) -> None: ...

global___RcmdUPsParam = RcmdUPsParam

@typing_extensions.final
class Relation(google.protobuf.message.Message):
    """关注关系"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    status: global___RelationStatus.ValueType
    """关注状态"""
    is_follow: builtins.int
    """关注"""
    is_followed: builtins.int
    """被关注"""
    title: builtins.str
    """文案"""
    def __init__(
        self,
        *,
        status: global___RelationStatus.ValueType = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "is_followed", b"is_followed", "status", b"status", "title", b"title"]) -> None: ...

global___Relation = Relation

@typing_extensions.final
class ShareChannel(google.protobuf.message.Message):
    """分享渠道组件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """分享名称"""
    image: builtins.str
    """分享按钮图片"""
    channel: builtins.str
    """分享渠道"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        image: builtins.str = ...,
        channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel", b"channel", "image", b"image", "name", b"name"]) -> None: ...

global___ShareChannel = ShareChannel

@typing_extensions.final
class SortType(google.protobuf.message.Message):
    """排序类型"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORT_TYPE_FIELD_NUMBER: builtins.int
    SORT_TYPE_NAME_FIELD_NUMBER: builtins.int
    sort_type: builtins.int
    """排序策略
    1:推荐排序 2:最常访问 3:最近关注
    """
    sort_type_name: builtins.str
    """排序策略名称"""
    def __init__(
        self,
        *,
        sort_type: builtins.int = ...,
        sort_type_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort_type", b"sort_type", "sort_type_name", b"sort_type_name"]) -> None: ...

global___SortType = SortType

@typing_extensions.final
class ThreePointAttention(google.protobuf.message.Message):
    """三点-关注"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTENTION_ICON_FIELD_NUMBER: builtins.int
    ATTENTION_TEXT_FIELD_NUMBER: builtins.int
    NOT_ATTENTION_ICON_FIELD_NUMBER: builtins.int
    NOT_ATTENTION_TEXT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    attention_icon: builtins.str
    """attention icon"""
    attention_text: builtins.str
    """关注时显示的文案"""
    not_attention_icon: builtins.str
    """not attention icon"""
    not_attention_text: builtins.str
    """未关注时显示的文案"""
    status: global___ThreePointAttentionStatus.ValueType
    """当前关注状态"""
    def __init__(
        self,
        *,
        attention_icon: builtins.str = ...,
        attention_text: builtins.str = ...,
        not_attention_icon: builtins.str = ...,
        not_attention_text: builtins.str = ...,
        status: global___ThreePointAttentionStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention_icon", b"attention_icon", "attention_text", b"attention_text", "not_attention_icon", b"not_attention_icon", "not_attention_text", b"not_attention_text", "status", b"status"]) -> None: ...

global___ThreePointAttention = ThreePointAttention

@typing_extensions.final
class ThreePointAutoPlay(google.protobuf.message.Message):
    """三点-自动播放 旧版不维护"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPEN_ICON_FIELD_NUMBER: builtins.int
    OPEN_TEXT_FIELD_NUMBER: builtins.int
    CLOSE_ICON_FIELD_NUMBER: builtins.int
    CLOSE_TEXT_FIELD_NUMBER: builtins.int
    OPEN_TEXT_V2_FIELD_NUMBER: builtins.int
    CLOSE_TEXT_V2_FIELD_NUMBER: builtins.int
    ONLY_ICON_FIELD_NUMBER: builtins.int
    ONLY_TEXT_FIELD_NUMBER: builtins.int
    OPEN_ICON_V2_FIELD_NUMBER: builtins.int
    CLOSE_ICON_V2_FIELD_NUMBER: builtins.int
    open_icon: builtins.str
    """open icon"""
    open_text: builtins.str
    """开启时显示文案"""
    close_icon: builtins.str
    """close icon"""
    close_text: builtins.str
    """关闭时显示文案"""
    open_text_v2: builtins.str
    """开启时显示文案v2"""
    close_text_v2: builtins.str
    """关闭时显示文案v2"""
    only_icon: builtins.str
    """仅wifi/免流 icon"""
    only_text: builtins.str
    """仅wifi/免流 文案"""
    open_icon_v2: builtins.str
    """open icon v2"""
    close_icon_v2: builtins.str
    """close icon v2"""
    def __init__(
        self,
        *,
        open_icon: builtins.str = ...,
        open_text: builtins.str = ...,
        close_icon: builtins.str = ...,
        close_text: builtins.str = ...,
        open_text_v2: builtins.str = ...,
        close_text_v2: builtins.str = ...,
        only_icon: builtins.str = ...,
        only_text: builtins.str = ...,
        open_icon_v2: builtins.str = ...,
        close_icon_v2: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["close_icon", b"close_icon", "close_icon_v2", b"close_icon_v2", "close_text", b"close_text", "close_text_v2", b"close_text_v2", "only_icon", b"only_icon", "only_text", b"only_text", "open_icon", b"open_icon", "open_icon_v2", b"open_icon_v2", "open_text", b"open_text", "open_text_v2", b"open_text_v2"]) -> None: ...

global___ThreePointAutoPlay = ThreePointAutoPlay

@typing_extensions.final
class ThreePointDefault(google.protobuf.message.Message):
    """三点-默认结构(使用此背景、举报、删除)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转链接"""
    id: builtins.str
    """id"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "id", b"id", "title", b"title", "uri", b"uri"]) -> None: ...

global___ThreePointDefault = ThreePointDefault

@typing_extensions.final
class ThreePointDislike(google.protobuf.message.Message):
    """三点-不感兴趣"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title"]) -> None: ...

global___ThreePointDislike = ThreePointDislike

@typing_extensions.final
class ThreePointFavorite(google.protobuf.message.Message):
    """三点-收藏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IS_FAVOURITE_FIELD_NUMBER: builtins.int
    CANCEL_ICON_FIELD_NUMBER: builtins.int
    CANCEL_TITLE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    id: builtins.int
    """物料ID"""
    is_favourite: builtins.bool
    """是否订阅"""
    cancel_icon: builtins.str
    """取消收藏图标"""
    cancel_title: builtins.str
    """取消收藏文案"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        id: builtins.int = ...,
        is_favourite: builtins.bool = ...,
        cancel_icon: builtins.str = ...,
        cancel_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cancel_icon", b"cancel_icon", "cancel_title", b"cancel_title", "icon", b"icon", "id", b"id", "is_favourite", b"is_favourite", "title", b"title"]) -> None: ...

global___ThreePointFavorite = ThreePointFavorite

@typing_extensions.final
class ThreePointItem(google.protobuf.message.Message):
    """三点Item"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DEFAULT_FIELD_NUMBER: builtins.int
    AUTO_PLAYER_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    ATTENTION_FIELD_NUMBER: builtins.int
    WAIT_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    FAVORITE_FIELD_NUMBER: builtins.int
    type: global___ThreePointType.ValueType
    """类型"""
    @property
    def default(self) -> global___ThreePointDefault:
        """默认结构"""
    @property
    def auto_player(self) -> global___ThreePointAutoPlay:
        """自动播放"""
    @property
    def share(self) -> global___ThreePointShare:
        """分享"""
    @property
    def attention(self) -> global___ThreePointAttention:
        """关注"""
    @property
    def wait(self) -> global___ThreePointWait:
        """稍后在看"""
    @property
    def dislike(self) -> global___ThreePointDislike:
        """不感兴趣"""
    @property
    def favorite(self) -> global___ThreePointFavorite:
        """收藏"""
    def __init__(
        self,
        *,
        type: global___ThreePointType.ValueType = ...,
        default: global___ThreePointDefault | None = ...,
        auto_player: global___ThreePointAutoPlay | None = ...,
        share: global___ThreePointShare | None = ...,
        attention: global___ThreePointAttention | None = ...,
        wait: global___ThreePointWait | None = ...,
        dislike: global___ThreePointDislike | None = ...,
        favorite: global___ThreePointFavorite | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attention", b"attention", "auto_player", b"auto_player", "default", b"default", "dislike", b"dislike", "favorite", b"favorite", "item", b"item", "share", b"share", "wait", b"wait"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention", "auto_player", b"auto_player", "default", b"default", "dislike", b"dislike", "favorite", b"favorite", "item", b"item", "share", b"share", "type", b"type", "wait", b"wait"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["default", "auto_player", "share", "attention", "wait", "dislike", "favorite"] | None: ...

global___ThreePointItem = ThreePointItem

@typing_extensions.final
class ThreePointShare(google.protobuf.message.Message):
    """三点-分享"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    @property
    def channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointShareChannel]:
        """分享渠道"""
    channel_name: builtins.str
    """分享渠道名"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        channel: collections.abc.Iterable[global___ThreePointShareChannel] | None = ...,
        channel_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel", b"channel", "channel_name", b"channel_name", "icon", b"icon", "title", b"title"]) -> None: ...

global___ThreePointShare = ThreePointShare

@typing_extensions.final
class ThreePointShareChannel(google.protobuf.message.Message):
    """三点-分享渠道"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """名称"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title"]) -> None: ...

global___ThreePointShareChannel = ThreePointShareChannel

@typing_extensions.final
class ThreePointWait(google.protobuf.message.Message):
    """三点-稍后在看"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITION_ICON_FIELD_NUMBER: builtins.int
    ADDITION_TEXT_FIELD_NUMBER: builtins.int
    NO_ADDITION_ICON_FIELD_NUMBER: builtins.int
    NO_ADDITION_TEXT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    addition_icon: builtins.str
    """addition icon"""
    addition_text: builtins.str
    """已添加时的文案"""
    no_addition_icon: builtins.str
    """no addition icon"""
    no_addition_text: builtins.str
    """未添加时的文案"""
    id: builtins.int
    """avid"""
    def __init__(
        self,
        *,
        addition_icon: builtins.str = ...,
        addition_text: builtins.str = ...,
        no_addition_icon: builtins.str = ...,
        no_addition_text: builtins.str = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_icon", b"addition_icon", "addition_text", b"addition_text", "id", b"id", "no_addition_icon", b"no_addition_icon", "no_addition_text", b"no_addition_text"]) -> None: ...

global___ThreePointWait = ThreePointWait

@typing_extensions.final
class TopicButton(google.protobuf.message.Message):
    """话题广场操作按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    JUMP_URI_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """按钮图标"""
    title: builtins.str
    """按钮文案"""
    jump_uri: builtins.str
    """跳转"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        jump_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "jump_uri", b"jump_uri", "title", b"title"]) -> None: ...

global___TopicButton = TopicButton

@typing_extensions.final
class TopicList(google.protobuf.message.Message):
    """综合页-话题广场"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TOPIC_LIST_ITEM_FIELD_NUMBER: builtins.int
    ACT_BUTTON_FIELD_NUMBER: builtins.int
    MORE_BUTTON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """模块标题"""
    @property
    def topic_list_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicListItem]:
        """话题列表"""
    @property
    def act_button(self) -> global___TopicButton:
        """发起活动"""
    @property
    def more_button(self) -> global___TopicButton:
        """查看更多"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        topic_list_item: collections.abc.Iterable[global___TopicListItem] | None = ...,
        act_button: global___TopicButton | None = ...,
        more_button: global___TopicButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["act_button", b"act_button", "more_button", b"more_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_button", b"act_button", "more_button", b"more_button", "title", b"title", "topic_list_item", b"topic_list_item"]) -> None: ...

global___TopicList = TopicList

@typing_extensions.final
class TopicListItem(google.protobuf.message.Message):
    """综合页-话题广场-话题"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    ICON_TITLE_FIELD_NUMBER: builtins.int
    TOPIC_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """前置图标"""
    icon_title: builtins.str
    """前置图标文案"""
    topic_id: builtins.int
    """话题id"""
    topic_name: builtins.str
    """话题名"""
    url: builtins.str
    """跳转链接"""
    pos: builtins.int
    """卡片位次"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        icon_title: builtins.str = ...,
        topic_id: builtins.int = ...,
        topic_name: builtins.str = ...,
        url: builtins.str = ...,
        pos: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "icon_title", b"icon_title", "pos", b"pos", "topic_id", b"topic_id", "topic_name", b"topic_name", "url", b"url"]) -> None: ...

global___TopicListItem = TopicListItem

@typing_extensions.final
class Unfollow(google.protobuf.message.Message):
    """综合页-无关注列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题展示文案"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UnfollowUserItem]:
        """无关注列表"""
    TrackId: builtins.str
    """trackID"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        list: collections.abc.Iterable[global___UnfollowUserItem] | None = ...,
        TrackId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["TrackId", b"TrackId", "list", b"list", "title", b"title"]) -> None: ...

global___Unfollow = Unfollow

@typing_extensions.final
class UnfollowUserItem(google.protobuf.message.Message):
    """综合页-无关注列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_UPDATE_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    has_update: builtins.bool
    """是否有更新"""
    face: builtins.str
    """up主头像"""
    name: builtins.str
    """up主昵称"""
    uid: builtins.int
    """up主uid"""
    pos: builtins.int
    """排序字段 从1开始"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
    sign: builtins.str
    """up介绍"""
    label: builtins.str
    """标签信息"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    def __init__(
        self,
        *,
        has_update: builtins.bool = ...,
        face: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.int = ...,
        pos: builtins.int = ...,
        live_state: global___LiveState.ValueType = ...,
        official: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        sign: builtins.str = ...,
        label: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "official", b"official", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "face", b"face", "has_update", b"has_update", "label", b"label", "live_state", b"live_state", "name", b"name", "official", b"official", "pos", b"pos", "sign", b"sign", "uid", b"uid", "vip", b"vip"]) -> None: ...

global___UnfollowUserItem = UnfollowUserItem

@typing_extensions.final
class UpListItem(google.protobuf.message.Message):
    """动态顶部up列表-up主信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_UPDATE_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    USER_ITEM_TYPE_FIELD_NUMBER: builtins.int
    DISPLAY_STYLE_DAY_FIELD_NUMBER: builtins.int
    DISPLAY_STYLE_NIGHT_FIELD_NUMBER: builtins.int
    STYLE_ID_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    SEPARATOR_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    IS_RECALL_FIELD_NUMBER: builtins.int
    has_update: builtins.bool
    """是否有更新"""
    face: builtins.str
    """up主头像"""
    name: builtins.str
    """up主昵称"""
    uid: builtins.int
    """up主uid"""
    pos: builtins.int
    """排序字段 从1开始"""
    user_item_type: global___UserItemType.ValueType
    """用户类型"""
    @property
    def display_style_day(self) -> global___UserItemStyle:
        """直播头像样式-日"""
    @property
    def display_style_night(self) -> global___UserItemStyle:
        """直播头像样式-夜"""
    style_id: builtins.int
    """直播埋点"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    separator: builtins.bool
    """分割线"""
    uri: builtins.str
    """跳转"""
    is_recall: builtins.bool
    """UP主预约上报使用"""
    def __init__(
        self,
        *,
        has_update: builtins.bool = ...,
        face: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.int = ...,
        pos: builtins.int = ...,
        user_item_type: global___UserItemType.ValueType = ...,
        display_style_day: global___UserItemStyle | None = ...,
        display_style_night: global___UserItemStyle | None = ...,
        style_id: builtins.int = ...,
        live_state: global___LiveState.ValueType = ...,
        separator: builtins.bool = ...,
        uri: builtins.str = ...,
        is_recall: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display_style_day", b"display_style_day", "display_style_night", b"display_style_night"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_style_day", b"display_style_day", "display_style_night", b"display_style_night", "face", b"face", "has_update", b"has_update", "is_recall", b"is_recall", "live_state", b"live_state", "name", b"name", "pos", b"pos", "separator", b"separator", "style_id", b"style_id", "uid", b"uid", "uri", b"uri", "user_item_type", b"user_item_type"]) -> None: ...

global___UpListItem = UpListItem

@typing_extensions.final
class UpListMoreLabel(google.protobuf.message.Message):
    """最常访问-查看更多"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """文案"""
    uri: builtins.str
    """跳转地址"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title", b"title", "uri", b"uri"]) -> None: ...

global___UpListMoreLabel = UpListMoreLabel

@typing_extensions.final
class UserInfo(google.protobuf.message.Message):
    """用户信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    NAMEPLATE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    name: builtins.str
    """用户昵称"""
    face: builtins.str
    """用户头像"""
    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
    @property
    def live(self) -> global___LiveInfo:
        """直播信息"""
    uri: builtins.str
    """空间页跳转链接"""
    @property
    def pendant(self) -> global___UserPendant:
        """挂件信息"""
    @property
    def nameplate(self) -> global___Nameplate:
        """认证名牌"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        official: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        live: global___LiveInfo | None = ...,
        uri: builtins.str = ...,
        pendant: global___UserPendant | None = ...,
        nameplate: global___Nameplate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live", b"live", "nameplate", b"nameplate", "official", b"official", "pendant", b"pendant", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "live", b"live", "mid", b"mid", "name", b"name", "nameplate", b"nameplate", "official", b"official", "pendant", b"pendant", "uri", b"uri", "vip", b"vip"]) -> None: ...

global___UserInfo = UserInfo

@typing_extensions.final
class UserItemStyle(google.protobuf.message.Message):
    """直播头像样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECT_TEXT_FIELD_NUMBER: builtins.int
    RECT_TEXT_COLOR_FIELD_NUMBER: builtins.int
    RECT_ICON_FIELD_NUMBER: builtins.int
    RECT_BG_COLOR_FIELD_NUMBER: builtins.int
    OUTER_ANIMATION_FIELD_NUMBER: builtins.int
    rect_text: builtins.str
    """"""
    rect_text_color: builtins.str
    """"""
    rect_icon: builtins.str
    """"""
    rect_bg_color: builtins.str
    """"""
    outer_animation: builtins.str
    """"""
    def __init__(
        self,
        *,
        rect_text: builtins.str = ...,
        rect_text_color: builtins.str = ...,
        rect_icon: builtins.str = ...,
        rect_bg_color: builtins.str = ...,
        outer_animation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outer_animation", b"outer_animation", "rect_bg_color", b"rect_bg_color", "rect_icon", b"rect_icon", "rect_text", b"rect_text", "rect_text_color", b"rect_text_color"]) -> None: ...

global___UserItemStyle = UserItemStyle

@typing_extensions.final
class UserPendant(google.protobuf.message.Message):
    """头像挂件信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """pid"""
    name: builtins.str
    """名称"""
    image: builtins.str
    """图片链接"""
    expire: builtins.int
    """有效期"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        name: builtins.str = ...,
        image: builtins.str = ...,
        expire: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire", b"expire", "image", b"image", "name", b"name", "pid", b"pid"]) -> None: ...

global___UserPendant = UserPendant

@typing_extensions.final
class VideoBadge(google.protobuf.message.Message):
    """角标信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    BG_ALPHA_FIELD_NUMBER: builtins.int
    BG_ALPHA_NIGHT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文案"""
    text_color: builtins.str
    """文案颜色-日间"""
    text_color_night: builtins.str
    """文案颜色-夜间"""
    bg_color: builtins.str
    """背景颜色-日间"""
    bg_color_night: builtins.str
    """背景颜色-夜间"""
    border_color: builtins.str
    """边框颜色-日间"""
    border_color_night: builtins.str
    """边框颜色-夜间"""
    bg_style: builtins.int
    """样式"""
    bg_alpha: builtins.int
    """背景透明度-日间"""
    bg_alpha_night: builtins.int
    """背景透明度-夜间"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
        bg_alpha: builtins.int = ...,
        bg_alpha_night: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_alpha", b"bg_alpha", "bg_alpha_night", b"bg_alpha_night", "bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___VideoBadge = VideoBadge

@typing_extensions.final
class VipInfo(google.protobuf.message.Message):
    """大会员信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    AVATAR_SUBSCRIPT_FIELD_NUMBER: builtins.int
    NICKNAME_COLOR_FIELD_NUMBER: builtins.int
    Type: builtins.int
    """大会员类型"""
    status: builtins.int
    """大会员状态"""
    due_date: builtins.int
    """到期时间"""
    @property
    def label(self) -> global___VipLabel:
        """标签"""
    theme_type: builtins.int
    """主题"""
    avatar_subscript: builtins.int
    """大会员角标
    0:无角标 1:粉色大会员角标 2:绿色小会员角标
    """
    nickname_color: builtins.str
    """昵称色值，可能为空，色值示例：#FFFB9E60"""
    def __init__(
        self,
        *,
        Type: builtins.int = ...,
        status: builtins.int = ...,
        due_date: builtins.int = ...,
        label: global___VipLabel | None = ...,
        theme_type: builtins.int = ...,
        avatar_subscript: builtins.int = ...,
        nickname_color: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Type", b"Type", "avatar_subscript", b"avatar_subscript", "due_date", b"due_date", "label", b"label", "nickname_color", b"nickname_color", "status", b"status", "theme_type", b"theme_type"]) -> None: ...

global___VipInfo = VipInfo

@typing_extensions.final
class VipLabel(google.protobuf.message.Message):
    """大会员标签"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LABEL_THEME_FIELD_NUMBER: builtins.int
    path: builtins.str
    """图片地址"""
    text: builtins.str
    """文本值"""
    label_theme: builtins.str
    """对应颜色类型"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        text: builtins.str = ...,
        label_theme: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["label_theme", b"label_theme", "path", b"path", "text", b"text"]) -> None: ...

global___VipLabel = VipLabel

@typing_extensions.final
class Weight(google.protobuf.message.Message):
    """提权样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """提权展示标题"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WeightItem]:
        """下拉框内容"""
    icon: builtins.str
    """icon"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        items: collections.abc.Iterable[global___WeightItem] | None = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "items", b"items", "title", b"title"]) -> None: ...

global___Weight = Weight

@typing_extensions.final
class WeightButton(google.protobuf.message.Message):
    """热门默认跳转按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JUMP_URL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    jump_url: builtins.str
    title: builtins.str
    """展示文案"""
    def __init__(
        self,
        *,
        jump_url: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url", b"jump_url", "title", b"title"]) -> None: ...

global___WeightButton = WeightButton

@typing_extensions.final
class WeightDislike(google.protobuf.message.Message):
    """提权不感兴趣"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEED_BACK_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    feed_back_type: builtins.str
    """负反馈业务类型 作为客户端调用负反馈接口的参数"""
    title: builtins.str
    """展示文案"""
    def __init__(
        self,
        *,
        feed_back_type: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feed_back_type", b"feed_back_type", "title", b"title"]) -> None: ...

global___WeightDislike = WeightDislike

@typing_extensions.final
class WeightItem(google.protobuf.message.Message):
    """提权样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    type: global___WeightType.ValueType
    """类型"""
    @property
    def button(self) -> global___WeightButton:
        """热门默认跳转按钮"""
    @property
    def dislike(self) -> global___WeightDislike:
        """提权不感兴趣"""
    def __init__(
        self,
        *,
        type: global___WeightType.ValueType = ...,
        button: global___WeightButton | None = ...,
        dislike: global___WeightDislike | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "dislike", b"dislike", "item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "dislike", b"dislike", "item", b"item", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["button", "dislike"] | None: ...

global___WeightItem = WeightItem
